import 'package:flutter/material.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart' show Constant;

///
///语言文字国际化类
///
class AppLocalizations {
  AppLocalizations({required Locale locale}) {
    _languageCode = locale.languageCode.toLowerCase();
  }

  ///默认的语言环境
  static const defaultCode = 'en';

  ///当前的语言环境
  static String _languageCode = 'zh';

  ///读取对应语言的文字集合
  static Map<String, String> get _localizedValueMap => (_localizedValues[_languageCode] ?? _localizedValues[defaultCode])!;

  ///读取当前的语言环境
  static String get languageCode => _languageCode;

  ///AppLocalizations的Delegate的实例
  static const LocalizationsDelegate<AppLocalizations> delegate = _AppLocalizationsDelegate();

  ///添加或覆盖字段值
  static void setLocalizedValues(Map<String, Map<String, String>> customValues) => customValues.forEach((k, v) => _localizedValues[k]?.addAll(v));

  ///根据[key]从[Constant.constMap]读取对应语言的文字描述
  static String modelConstMapText(int key) => (Constant.constMap[_languageCode] ?? Constant.constMap[defaultCode])?[key] ?? key.toString();

  static String get appLoginNormalTitle => _localizedValueMap['appLoginNormalTitle']!;
  static String get appLoginNormalBtnSure => _localizedValueMap['appLoginNormalBtnSure']!;
  static String get appLoginNormalThirdMethod => _localizedValueMap['appLoginNormalThirdMethod']!;
  static String get appLoginNormalNoWechatHint => _localizedValueMap['appLoginNormalNoWechatHint']!;
  static String get appLoginRegisterTitle => _localizedValueMap['appLoginRegisterTitle']!;
  static String get appLoginRegisterBtnSure => _localizedValueMap['appLoginRegisterBtnSure']!;
  static String get appLoginForgetPwdTitle => _localizedValueMap['appLoginForgetPwdTitle']!;
  static String get appLoginForgetPwdBtnSure => _localizedValueMap['appLoginForgetPwdBtnSure']!;
  static String get appLoginPhoneCodeTitle => _localizedValueMap['appLoginPhoneCodeTitle']!;
  static String get appLoginPhoneCodeBtnSure => _localizedValueMap['appLoginPhoneCodeBtnSure']!;
  static String get appLoginFieldLabelNo => _localizedValueMap['appLoginFieldLabelNo']!;
  static String get appLoginFieldLabelPwd => _localizedValueMap['appLoginFieldLabelPwd']!;
  static String get appLoginFieldLabelPhone => _localizedValueMap['appLoginFieldLabelPhone']!;
  static String get appLoginFieldLabelCode => _localizedValueMap['appLoginFieldLabelCode']!;
  static String get appLoginFieldLabelNewPwd => _localizedValueMap['appLoginFieldLabelNewPwd']!;
  static String get appLoginFieldHintNo => _localizedValueMap['appLoginFieldHintNo']!;
  static String get appLoginFieldHintPwd => _localizedValueMap['appLoginFieldHintPwd']!;
  static String get appLoginFieldHintPhone => _localizedValueMap['appLoginFieldHintPhone']!;
  static String get appLoginFieldHintCode => _localizedValueMap['appLoginFieldHintCode']!;
  static String get appLoginFieldHintNewNo => _localizedValueMap['appLoginFieldHintNewNo']!;
  static String get appLoginFieldHintNewPwd => _localizedValueMap['appLoginFieldHintNewPwd']!;
  static String get appLoginFieldBtnSendCode => _localizedValueMap['appLoginFieldBtnSendCode']!;
  static String get appLoginProtoReadAgreeBody => _localizedValueMap['appLoginProtoReadAgreeBody']!;
  static String get appLoginProtoReadAgreeAlert => _localizedValueMap['appLoginProtoReadAgreeAlert']!;
  static String get appLoginProtoBtnUserText => _localizedValueMap['appLoginProtoBtnUserText']!;
  static String get appLoginProtoAnd => _localizedValueMap['appLoginProtoAnd']!;
  static String get appLoginProtoBtnProvText => _localizedValueMap['appLoginProtoBtnProvText']!;
  static String get appLoginProtoAlertBtnNo => _localizedValueMap['appLoginProtoAlertBtnNo']!;
  static String get appLoginProtoAlertBtnYes => _localizedValueMap['appLoginProtoAlertBtnYes']!;
  static String get appLoginSureLoading => _localizedValueMap['appLoginSureLoading']!;
  static String get appLoginSendLoading => _localizedValueMap['appLoginSendLoading']!;

  static String get appHomeTabItemCustom1 => _localizedValueMap['appHomeTabItemCustom1']!;
  static String get appHomeTabItemCustom2 => _localizedValueMap['appHomeTabItemCustom2']!;
  static String get appHomeTabItemSession => _localizedValueMap['appHomeTabItemSession']!;
  static String get appHomeTabItemUserme => _localizedValueMap['appHomeTabItemUserme']!;
  static String get appHomeUserExpiredHint => _localizedValueMap['appHomeUserExpiredHint']!;
  static String get appHomeUserExpiredSure => _localizedValueMap['appHomeUserExpiredSure']!;

  static String get appWebViewActionBtnMenuTip => _localizedValueMap['appWebViewActionBtnMenuTip']!;
  static String get appWebViewMenuItemShareToUser => _localizedValueMap['appWebViewMenuItemShareToUser']!;
  static String get appWebViewMenuItemShareToTeam => _localizedValueMap['appWebViewMenuItemShareToTeam']!;
  static String get appWebViewMenuItemReport => _localizedValueMap['appWebViewMenuItemReport']!;
  static String get appWebViewMenuItemReload => _localizedValueMap['appWebViewMenuItemReload']!;
  static String get appWebViewMenuItemCancel => _localizedValueMap['appWebViewMenuItemCancel']!;
  static String get appWebViewPageShareFinished => _localizedValueMap['appWebViewPageShareFinished']!;

  static String get sessionHomeActionBtnContactTip => _localizedValueMap['sessionHomeActionBtnContactTip']!;
  static String get sessionHomeActionBtnQrScanTip => _localizedValueMap['sessionHomeActionBtnQrScanTip']!;
  static String get sessionHomeListItemBtnReaded => _localizedValueMap['sessionHomeListItemBtnReaded']!;
  static String get sessionHomeListItemBtnRemove => _localizedValueMap['sessionHomeListItemBtnRemove']!;

  static String get sessionChatActionBtnDetailTip => _localizedValueMap['sessionChatActionBtnDetailTip']!;
  static String get sessionChatKeyboardMenuItemGallery => _localizedValueMap['sessionChatKeyboardMenuItemGallery']!;
  static String get sessionChatKeyboardMenuItemCamera => _localizedValueMap['sessionChatKeyboardMenuItemCamera']!;
  static String get sessionChatKeyboardMenuItemVoice => _localizedValueMap['sessionChatKeyboardMenuItemVoice']!;
  static String get sessionChatKeyboardMenuItemVideo => _localizedValueMap['sessionChatKeyboardMenuItemVideo']!;
  static String get sessionChatKeyboardMenuItemScreen => _localizedValueMap['sessionChatKeyboardMenuItemScreen']!;
  static String get sessionChatKeyboardMenuItemLocaltion => _localizedValueMap['sessionChatKeyboardMenuItemLocaltion']!;
  static String get sessionChatKeyboardMenuItemLocalreal => _localizedValueMap['sessionChatKeyboardMenuItemLocalreal']!;
  static String get sessionChatKeyboardMenuItemRedpack => _localizedValueMap['sessionChatKeyboardMenuItemRedpack']!;
  static String get sessionChatKeyboardInputHint => _localizedValueMap['sessionChatKeyboardInputHint']!;
  static String get sessionChatImageEditTitle => _localizedValueMap['sessionChatImageEditTitle']!;
  static String get sessionChatTeamusersPickerTitle => _localizedValueMap['sessionChatTeamusersPickerTitle']!;
  static String get sessionChatRealtimeDeviceIsBusy => _localizedValueMap['sessionChatRealtimeDeviceIsBusy']!;
  static String get sessionChatFileUploadLoading => _localizedValueMap['sessionChatFileUploadLoading']!;

  static String get sessionAmapActionBtnSure => _localizedValueMap['sessionAmapActionBtnSure']!;
  static String get sessionAmapTitleLocationView => _localizedValueMap['sessionAmapTitleLocationView']!;
  static String get sessionAmapTitleShareMessage => _localizedValueMap['sessionAmapTitleShareMessage']!;
  static String get sessionAmapTitleRealtimeShare => _localizedValueMap['sessionAmapTitleRealtimeShare']!;
  static String get sessionAmapNavigateNameAmap => _localizedValueMap['sessionAmapNavigateNameAmap']!;
  static String get sessionAmapNavigateNameBaidu => _localizedValueMap['sessionAmapNavigateNameBaidu']!;
  static String get sessionAmapNavigateNameTencent => _localizedValueMap['sessionAmapNavigateNameTencent']!;
  static String get sessionAmapNavigateNameApple => _localizedValueMap['sessionAmapNavigateNameApple']!;
  static String get sessionAmapNavigateNameGoogle => _localizedValueMap['sessionAmapNavigateNameGoogle']!;
  static String get sessionAmapNavigateCancel => _localizedValueMap['sessionAmapNavigateCancel']!;
  static String get sessionAmapPoiListBarTitle => _localizedValueMap['sessionAmapPoiListBarTitle']!;
  static String get sessionAmapDistanceKilometer => _localizedValueMap['sessionAmapDistanceKilometer']!;
  static String get sessionAmapDistanceMeter => _localizedValueMap['sessionAmapDistanceMeter']!;
  static String get sessionAmapEncodeLoading => _localizedValueMap['sessionAmapEncodeLoading']!;
  static String get sessionAmapUploadLoading => _localizedValueMap['sessionAmapUploadLoading']!;

  static String get sessionRealtimeTextWaiting => _localizedValueMap['sessionRealtimeTextWaiting']!;
  static String get sessionRealtimeTextChating => _localizedValueMap['sessionRealtimeTextChating']!;

  static String get sessionRedpackTitleNormal => _localizedValueMap['sessionRedpackTitleNormal']!;
  static String get sessionRedpackTitleLuckly => _localizedValueMap['sessionRedpackTitleLuckly']!;
  static String get sessionRedpackTextSwitchTo => _localizedValueMap['sessionRedpackTextSwitchTo']!;
  static String get sessionRedpackTextTotalMoney => _localizedValueMap['sessionRedpackTextTotalMoney']!;
  static String get sessionRedpackTextSingleMoney => _localizedValueMap['sessionRedpackTextSingleMoney']!;
  static String get sessionRedpackTextTotalCount => _localizedValueMap['sessionRedpackTextTotalCount']!;
  static String get sessionRedpackTextUnitMoney => _localizedValueMap['sessionRedpackTextUnitMoney']!;
  static String get sessionRedpackTextUnitCount => _localizedValueMap['sessionRedpackTextUnitCount']!;
  static String get sessionRedpackHintMoney => _localizedValueMap['sessionRedpackHintMoney']!;
  static String get sessionRedpackHintCount => _localizedValueMap['sessionRedpackHintCount']!;
  static String get sessionRedpackHintDesc => _localizedValueMap['sessionRedpackHintDesc']!;
  static String get sessionRedpackButtonSure => _localizedValueMap['sessionRedpackButtonSure']!;
  static String get sessionRedpackErrorMoney => _localizedValueMap['sessionRedpackErrorMoney']!;
  static String get sessionRedpackErrorCount => _localizedValueMap['sessionRedpackErrorCount']!;

  static String get sessionMessageRealtimeGoing => _localizedValueMap['sessionMessageRealtimeGoing']!;
  static String get sessionMessageRealtimeMissed => _localizedValueMap['sessionMessageRealtimeMissed']!;
  static String get sessionMessageRealtimeTotal => _localizedValueMap['sessionMessageRealtimeTotal']!;
  static String get sessionMessageRealtimeEndHint => _localizedValueMap['sessionMessageRealtimeEndHint']!;
  static String get sessionMessageRealtimeNotHint => _localizedValueMap['sessionMessageRealtimeNotHint']!;

  static String get contactHomeActionBtnUserSearchTip => _localizedValueMap['contactHomeActionBtnUserSearchTip']!;
  static String get contactHomeActionBtnTeamCreateTip => _localizedValueMap['contactHomeActionBtnTeamCreateTip']!;
  static String get contactHomeTabItemWaitships => _localizedValueMap['contactHomeTabItemWaitships']!;
  static String get contactHomeTabItemUserships => _localizedValueMap['contactHomeTabItemUserships']!;
  static String get contactHomeTabItemTeamships => _localizedValueMap['contactHomeTabItemTeamships']!;
  static String get contactHomeTeamCreateLoading => _localizedValueMap['contactHomeTeamCreateLoading']!;

  static String get contactAZListActionBtnSure => _localizedValueMap['contactAZListActionBtnSure']!;
  static String get contactAZListActionBtnPlusTip => _localizedValueMap['contactAZListActionBtnPlusTip']!;
  static String get contactAZListSuffixOfWaitships => _localizedValueMap['contactAZListSuffixOfWaitships']!;
  static String get contactAZListSuffixOfUserships => _localizedValueMap['contactAZListSuffixOfUserships']!;
  static String get contactAZListSuffixOfTeamships => _localizedValueMap['contactAZListSuffixOfTeamships']!;
  static String get contactAZListSuffixOfTeamusers => _localizedValueMap['contactAZListSuffixOfTeamusers']!;
  static String get contactAZListWaitshipsApplyEmpty => _localizedValueMap['contactAZListWaitshipsApplyEmpty']!;
  static String get contactAZListTeamUsersOwnerHint => _localizedValueMap['contactAZListTeamUsersOwnerHint']!;
  static String get contactAZListTeamUsersAdminHint => _localizedValueMap['contactAZListTeamUsersAdminHint']!;
  static String get contactAZListTeamUsersBtnAdminY => _localizedValueMap['contactAZListTeamUsersBtnAdminY']!;
  static String get contactAZListTeamUsersBtnAdminN => _localizedValueMap['contactAZListTeamUsersBtnAdminN']!;
  static String get contactAZListTeamUsersBtnRemove => _localizedValueMap['contactAZListTeamUsersBtnRemove']!;
  static String get contactAZListTeamUsersBtnQuit => _localizedValueMap['contactAZListTeamUsersBtnQuit']!;
  static String get contactAZListTeamUsersActionLoading => _localizedValueMap['contactAZListTeamUsersActionLoading']!;

  static String get contactFinderInputHint => _localizedValueMap['contactFinderInputHint']!;
  static String get contactFinderActionBtnSure => _localizedValueMap['contactFinderActionBtnSure']!;
  static String get contactFinderItemResEmptyText => _localizedValueMap['contactFinderItemResEmptyText']!;
  static String get contactFinderSureLoading => _localizedValueMap['contactFinderSureLoading']!;

  static String get contactUserInfoActionBtnMenuTip => _localizedValueMap['contactUserInfoActionBtnMenuTip']!;
  static String get contactUserInfoListHeadNoTitle => _localizedValueMap['contactUserInfoListHeadNoTitle']!;
  static String get contactUserInfoListHeadNoEmpty => _localizedValueMap['contactUserInfoListHeadNoEmpty']!;
  static String get contactUserInfoListItemAliasTitle => _localizedValueMap['contactUserInfoListItemAliasTitle']!;
  static String get contactUserInfoListItemAddrTitle => _localizedValueMap['contactUserInfoListItemAddrTitle']!;
  static String get contactUserInfoListItemDescTitle => _localizedValueMap['contactUserInfoListItemDescTitle']!;
  static String get contactUserInfoListItemFromTitle => _localizedValueMap['contactUserInfoListItemFromTitle']!;
  static String get contactUserInfoListItemNoticeTitle => _localizedValueMap['contactUserInfoListItemNoticeTitle']!;
  static String get contactUserInfoListItemTopTitle => _localizedValueMap['contactUserInfoListItemTopTitle']!;
  static String get contactUserInfoListItemApplyTitle => _localizedValueMap['contactUserInfoListItemApplyTitle']!;
  static String get contactUserInfoListItemApplyEmpty => _localizedValueMap['contactUserInfoListItemApplyEmpty']!;
  static String get contactUserInfoListItemChatBtnStart => _localizedValueMap['contactUserInfoListItemChatBtnStart']!;
  static String get contactUserInfoListItemApplyBtnSend => _localizedValueMap['contactUserInfoListItemApplyBtnSend']!;
  static String get contactUserInfoListItemApplyBtnAgree => _localizedValueMap['contactUserInfoListItemApplyBtnAgree']!;
  static String get contactUserInfoListItemApplyBtnReject => _localizedValueMap['contactUserInfoListItemApplyBtnReject']!;
  static String get contactUserInfoListItemApplyWaitHint => _localizedValueMap['contactUserInfoListItemApplyWaitHint']!;
  static String get contactUserInfoMenuItemShareToUser => _localizedValueMap['contactUserInfoMenuItemShareToUser']!;
  static String get contactUserInfoMenuItemShareToTeam => _localizedValueMap['contactUserInfoMenuItemShareToTeam']!;
  static String get contactUserInfoMenuItemReport => _localizedValueMap['contactUserInfoMenuItemReport']!;
  static String get contactUserInfoMenuItemRemove => _localizedValueMap['contactUserInfoMenuItemRemove']!;
  static String get contactUserInfoMenuItemCancel => _localizedValueMap['contactUserInfoMenuItemCancel']!;
  static String get contactUserInfoUserShipQueryLoading => _localizedValueMap['contactUserInfoUserShipQueryLoading']!;
  static String get contactUserInfoUserShipUpdateLoading => _localizedValueMap['contactUserInfoUserShipUpdateLoading']!;
  static String get contactUserInfoUserShipActionLoading => _localizedValueMap['contactUserInfoUserShipActionLoading']!;
  static String get contactUserInfoUserShipShareFinished => _localizedValueMap['contactUserInfoUserShipShareFinished']!;

  static String get contactTeamInfoActionBtnMenuTip => _localizedValueMap['contactTeamInfoActionBtnMenuTip']!;
  static String get contactTeamInfoListHeadTotalPreffix => _localizedValueMap['contactTeamInfoListHeadTotalPreffix']!;
  static String get contactTeamInfoListHeadTotalSuffix => _localizedValueMap['contactTeamInfoListHeadTotalSuffix']!;
  static String get contactTeamInfoListHeadMemberTitle => _localizedValueMap['contactTeamInfoListHeadMemberTitle']!;
  static String get contactTeamInfoListItemQrCodeTitle => _localizedValueMap['contactTeamInfoListItemQrCodeTitle']!;
  static String get contactTeamInfoListItemQrCodeHint => _localizedValueMap['contactTeamInfoListItemQrCodeHint']!;
  static String get contactTeamInfoListItemNickTitle => _localizedValueMap['contactTeamInfoListItemNickTitle']!;
  static String get contactTeamInfoListItemDescTitle => _localizedValueMap['contactTeamInfoListItemDescTitle']!;
  static String get contactTeamInfoListItemSettingsTitle => _localizedValueMap['contactTeamInfoListItemSettingsTitle']!;
  static String get contactTeamInfoListItemAliasTitle => _localizedValueMap['contactTeamInfoListItemAliasTitle']!;
  static String get contactTeamInfoListItemNoticeTitle => _localizedValueMap['contactTeamInfoListItemNoticeTitle']!;
  static String get contactTeamInfoListItemTopTitle => _localizedValueMap['contactTeamInfoListItemTopTitle']!;
  static String get contactTeamInfoListItemFromTitle => _localizedValueMap['contactTeamInfoListItemFromTitle']!;
  static String get contactTeamInfoListItemChatBtnStart => _localizedValueMap['contactTeamInfoListItemChatBtnStart']!;
  static String get contactTeamInfoListItemApplyBtnSend => _localizedValueMap['contactTeamInfoListItemApplyBtnSend']!;
  static String get contactTeamInfoMenuItemShareToUser => _localizedValueMap['contactTeamInfoMenuItemShareToUser']!;
  static String get contactTeamInfoMenuItemShareToTeam => _localizedValueMap['contactTeamInfoMenuItemShareToTeam']!;
  static String get contactTeamInfoMenuItemReport => _localizedValueMap['contactTeamInfoMenuItemReport']!;
  static String get contactTeamInfoMenuItemRemove => _localizedValueMap['contactTeamInfoMenuItemRemove']!;
  static String get contactTeamInfoMenuItemCancel => _localizedValueMap['contactTeamInfoMenuItemCancel']!;
  static String get contactTeamInfoTeamShipQueryLoading => _localizedValueMap['contactTeamInfoTeamShipQueryLoading']!;
  static String get contactTeamInfoTeamShipUpdateLoading => _localizedValueMap['contactTeamInfoTeamShipUpdateLoading']!;
  static String get contactTeamInfoTeamShipActionLoading => _localizedValueMap['contactTeamInfoTeamShipActionLoading']!;
  static String get contactTeamInfoTeamShipShareFinished => _localizedValueMap['contactTeamInfoTeamShipShareFinished']!;

  static String get contactEditorTitlePreffix => _localizedValueMap['contactEditorTitlePreffix']!;
  static String get contactEditorActionBtnSave => _localizedValueMap['contactEditorActionBtnSave']!;
  static String get contactEditorTeamOnText => _localizedValueMap['contactEditorTeamOnText']!;
  static String get contactEditorTeamOffText => _localizedValueMap['contactEditorTeamOffText']!;
  static String get contactEditorTeamByfind => _localizedValueMap['contactEditorTeamByfind']!;
  static String get contactEditorTeamBycode => _localizedValueMap['contactEditorTeamBycode']!;
  static String get contactEditorTeamBycard => _localizedValueMap['contactEditorTeamBycard']!;
  static String get contactEditorTeamByteam => _localizedValueMap['contactEditorTeamByteam']!;
  static String get contactEditorTeamNotice => _localizedValueMap['contactEditorTeamNotice']!;
  static String get contactEditorTeamSlient => _localizedValueMap['contactEditorTeamSlient']!;
  static String get contactEditorSaveLoading => _localizedValueMap['contactEditorSaveLoading']!;
  static String get contactEditorApplyLoading => _localizedValueMap['contactEditorApplyLoading']!;

  static String get usermeHomeActionBtnAppThemeTip => _localizedValueMap['usermeHomeActionBtnAppThemeTip']!;
  static String get usermeHomeActionBtnMyQrCodeTip => _localizedValueMap['usermeHomeActionBtnMyQrCodeTip']!;
  static String get usermeHomeActionBtnMyQrcodeHint => _localizedValueMap['usermeHomeActionBtnMyQrcodeHint']!;
  static String get usermeHomeListHeadMyNoTitle => _localizedValueMap['usermeHomeListHeadMyNoTitle']!;
  static String get usermeHomeListHeadMyNoEmpty => _localizedValueMap['usermeHomeListHeadMyNoEmpty']!;
  static String get usermeHomeListItemMyVipCentTitle => _localizedValueMap['usermeHomeListItemMyVipCentTitle']!;
  static String get usermeHomeListItemMyCollectTitle => _localizedValueMap['usermeHomeListItemMyCollectTitle']!;
  static String get usermeHomeListItemProtoUserTitle => _localizedValueMap['usermeHomeListItemProtoUserTitle']!;
  static String get usermeHomeListItemProtoPrivTitle => _localizedValueMap['usermeHomeListItemProtoPrivTitle']!;
  static String get usermeHomeListItemSettingsTitle => _localizedValueMap['usermeHomeListItemSettingsTitle']!;

  static String get usermeDetailTitle => _localizedValueMap['usermeDetailTitle']!;
  static String get usermeDetailListItemNoTitle => _localizedValueMap['usermeDetailListItemNoTitle']!;
  static String get usermeDetailListItemPwdTitle => _localizedValueMap['usermeDetailListItemPwdTitle']!;
  static String get usermeDetailListItemNickTitle => _localizedValueMap['usermeDetailListItemNickTitle']!;
  static String get usermeDetailListItemDescTitle => _localizedValueMap['usermeDetailListItemDescTitle']!;
  static String get usermeDetailListItemPhoneTitle => _localizedValueMap['usermeDetailListItemPhoneTitle']!;
  static String get usermeDetailListItemNameTitle => _localizedValueMap['usermeDetailListItemNameTitle']!;
  static String get usermeDetailListItemCardTitle => _localizedValueMap['usermeDetailListItemCardTitle']!;
  static String get usermeDetailListItemSexTitle => _localizedValueMap['usermeDetailListItemSexTitle']!;
  static String get usermeDetailListItemBirthTitle => _localizedValueMap['usermeDetailListItemBirthTitle']!;
  static String get usermeDetailListItemAddrTitle => _localizedValueMap['usermeDetailListItemAddrTitle']!;
  static String get usermeDetailMenuItemAlbum => _localizedValueMap['usermeDetailMenuItemAlbum']!;
  static String get usermeDetailMenuItemCamera => _localizedValueMap['usermeDetailMenuItemCamera']!;
  static String get usermeDetailMenuItemCancel => _localizedValueMap['usermeDetailMenuItemCancel']!;
  static String get usermeDetailHeadEditTitle => _localizedValueMap['usermeDetailHeadEditTitle']!;
  static String get usermeDetailSaveLoading => _localizedValueMap['usermeDetailSaveLoading']!;

  static String get usermeEditorTitlePreffix => _localizedValueMap['usermeEditorTitlePreffix']!;
  static String get usermeEditorActionBtnSave => _localizedValueMap['usermeEditorActionBtnSave']!;
  static String get usermeEditorNoHint => _localizedValueMap['usermeEditorNoHint']!;
  static String get usermeEditorNoHelper => _localizedValueMap['usermeEditorNoHelper']!;
  static String get usermeEditorPasswordCode => _localizedValueMap['usermeEditorPasswordCode']!;
  static String get usermeEditorPasswordCodeHint => _localizedValueMap['usermeEditorPasswordCodeHint']!;
  static String get usermeEditorPasswordPwd => _localizedValueMap['usermeEditorPasswordPwd']!;
  static String get usermeEditorPasswordPwdHint => _localizedValueMap['usermeEditorPasswordPwdHint']!;
  static String get usermeEditorPasswordUnbind => _localizedValueMap['usermeEditorPasswordUnbind']!;
  static String get usermeEditorPhoneOldCode => _localizedValueMap['usermeEditorPhoneOldCode']!;
  static String get usermeEditorPhoneOldCodeHint => _localizedValueMap['usermeEditorPhoneOldCodeHint']!;
  static String get usermeEditorPhoneNewPhone => _localizedValueMap['usermeEditorPhoneNewPhone']!;
  static String get usermeEditorPhoneNewPhoneHint => _localizedValueMap['usermeEditorPhoneNewPhoneHint']!;
  static String get usermeEditorPhoneNewCode => _localizedValueMap['usermeEditorPhoneNewCode']!;
  static String get usermeEditorPhoneNewCodeHint => _localizedValueMap['usermeEditorPhoneNewCodeHint']!;
  static String get usermeEditorRandcodeSend => _localizedValueMap['usermeEditorRandcodeSend']!;
  static String get usermeEditorChooseBirthday => _localizedValueMap['usermeEditorChooseBirthday']!;
  static String get usermeEditorAddrCountry => _localizedValueMap['usermeEditorAddrCountry']!;
  static String get usermeEditorAddrProvince => _localizedValueMap['usermeEditorAddrProvince']!;
  static String get usermeEditorAddrCity => _localizedValueMap['usermeEditorAddrCity']!;
  static String get usermeEditorAddrArea => _localizedValueMap['usermeEditorAddrArea']!;
  static String get usermeEditorSaveLoading => _localizedValueMap['usermeEditorSaveLoading']!;
  static String get usermeEditorSendLoading => _localizedValueMap['usermeEditorSendLoading']!;

  static String get usermeSettingsUserByfind => _localizedValueMap['usermeSettingsUserByfind']!;
  static String get usermeSettingsUserBycode => _localizedValueMap['usermeSettingsUserBycode']!;
  static String get usermeSettingsUserBycard => _localizedValueMap['usermeSettingsUserBycard']!;
  static String get usermeSettingsUserByteam => _localizedValueMap['usermeSettingsUserByteam']!;
  static String get usermeSettingsUserNotice => _localizedValueMap['usermeSettingsUserNotice']!;
  static String get usermeSettingsUserSlient => _localizedValueMap['usermeSettingsUserSlient']!;
  static String get usermeSettingsBtnLogout => _localizedValueMap['usermeSettingsBtnLogout']!;
  static String get usermeSettingsBoxLogoutHint => _localizedValueMap['usermeSettingsBoxLogoutHint']!;
  static String get usermeSettingsBoxLogoutCancel => _localizedValueMap['usermeSettingsBoxLogoutCancel']!;
  static String get usermeSettingsBoxLogoutSure => _localizedValueMap['usermeSettingsBoxLogoutSure']!;
  static String get usermeSettingsSaveLoading => _localizedValueMap['usermeSettingsSaveLoading']!;
  static String get usermeSettingsLogoutLoading => _localizedValueMap['usermeSettingsLogoutLoading']!;

  static String get androidNotificationChannelMessageId => 'androidNotificationChannelMessageId';
  static String get androidNotificationChannelMessageName => _localizedValueMap['androidNotificationChannelMessageName']!;
  static String get androidNotificationChannelMessageDesc => _localizedValueMap['androidNotificationChannelMessageDesc']!;
  static String get androidNotificationChannelRealtimeId => 'androidNotificationChannelRealtimeId';
  static String get androidNotificationChannelRealtimeName => _localizedValueMap['androidNotificationChannelRealtimeName']!;
  static String get androidNotificationChannelRealtimeDesc => _localizedValueMap['androidNotificationChannelRealtimeDesc']!;

  ///本地化字段集合
  static final Map<String, Map<String, String>> _localizedValues = {
    'zh': {
      'appLoginNormalTitle': '账号登录',
      'appLoginNormalBtnSure': '登录',
      'appLoginNormalThirdMethod': '或通过以下登录:',
      'appLoginNormalNoWechatHint': '请先安装微信',
      'appLoginRegisterTitle': '注册账号',
      'appLoginRegisterBtnSure': '注册',
      'appLoginForgetPwdTitle': '忘记密码',
      'appLoginForgetPwdBtnSure': '修改',
      'appLoginPhoneCodeTitle': '验证码登陆',
      'appLoginPhoneCodeBtnSure': '确定',
      'appLoginFieldLabelNo': '账号',
      'appLoginFieldLabelPwd': '密码',
      'appLoginFieldLabelPhone': '手机号',
      'appLoginFieldLabelCode': '验证码',
      'appLoginFieldLabelNewPwd': '新密码',
      'appLoginFieldHintNo': '请输入账号或手机号',
      'appLoginFieldHintPwd': '请输入8~32位密码',
      'appLoginFieldHintPhone': '请输入手机号码',
      'appLoginFieldHintCode': '请输入6位数字验证码',
      'appLoginFieldHintNewNo': '请输入8~32位账号 (字母/数字/下划线)',
      'appLoginFieldHintNewPwd': '请输入8~32位新密码',
      'appLoginFieldBtnSendCode': '发送',
      'appLoginProtoReadAgreeBody': '我已阅读并同意 ',
      'appLoginProtoReadAgreeAlert': '您已经仔细阅读并同意',
      'appLoginProtoBtnUserText': '用户协议',
      'appLoginProtoAnd': ' 和 ',
      'appLoginProtoBtnProvText': '隐私政策',
      'appLoginProtoAlertBtnNo': '不是',
      'appLoginProtoAlertBtnYes': '是的',
      'appLoginSureLoading': '登录中...',
      'appLoginSendLoading': '发送中...',
      'appHomeTabItemCustom1': '应用',
      'appHomeTabItemCustom2': '资讯',
      'appHomeTabItemSession': '会话',
      'appHomeTabItemUserme': '我的',
      'appHomeUserExpiredHint': '您当前的登录状态已经失效！',
      'appHomeUserExpiredSure': '我知道了',
      'appWebViewActionBtnMenuTip': '显示菜单',
      'appWebViewMenuItemShareToUser': '分享网页给好友',
      'appWebViewMenuItemShareToTeam': '分享网页到群组',
      'appWebViewMenuItemReport': '投诉这个网页',
      'appWebViewMenuItemReload': '重新加载网页',
      'appWebViewMenuItemCancel': '取消',
      'appWebViewPageShareFinished': '网页已分享',
      'sessionHomeActionBtnContactTip': '通讯录',
      'sessionHomeActionBtnQrScanTip': '扫二维码',
      'sessionHomeListItemBtnReaded': '标记已读',
      'sessionHomeListItemBtnRemove': '移除',
      'sessionChatActionBtnDetailTip': '会话信息',
      'sessionChatKeyboardMenuItemGallery': '相册',
      'sessionChatKeyboardMenuItemCamera': '拍摄',
      'sessionChatKeyboardMenuItemVoice': '语音电话',
      'sessionChatKeyboardMenuItemVideo': '视频电话',
      'sessionChatKeyboardMenuItemScreen': '屏幕共享',
      'sessionChatKeyboardMenuItemLocaltion': '位置分享',
      'sessionChatKeyboardMenuItemLocalreal': '实时位置',
      'sessionChatKeyboardMenuItemRedpack': '红包',
      'sessionChatKeyboardInputHint': '请使用键盘输入',
      'sessionChatImageEditTitle': '编辑图片',
      'sessionChatTeamusersPickerTitle': '选择群组成员',
      'sessionChatRealtimeDeviceIsBusy': '设备忙碌中...',
      'sessionChatFileUploadLoading': '上传中...',
      'sessionAmapActionBtnSure': '发送',
      'sessionAmapTitleLocationView': '位置信息',
      'sessionAmapTitleShareMessage': '位置分享',
      'sessionAmapTitleRealtimeShare': '实时位置共享',
      'sessionAmapNavigateNameAmap': '高德地图',
      'sessionAmapNavigateNameBaidu': '百度地图',
      'sessionAmapNavigateNameTencent': '腾讯地图',
      'sessionAmapNavigateNameApple': '苹果地图',
      'sessionAmapNavigateNameGoogle': '谷歌地图',
      'sessionAmapNavigateCancel': '取消',
      'sessionAmapPoiListBarTitle': '附近地点',
      'sessionAmapDistanceKilometer': 'km',
      'sessionAmapDistanceMeter': 'm',
      'sessionAmapEncodeLoading': '编码中...',
      'sessionAmapUploadLoading': '上传中...',
      'sessionRealtimeTextWaiting': '等待接听...',
      'sessionRealtimeTextChating': '正在通话中...',
      'sessionRedpackTitleNormal': '普通红包',
      'sessionRedpackTitleLuckly': '拼手气红包',
      'sessionRedpackTextSwitchTo': '切换为',
      'sessionRedpackTextTotalMoney': '总金额',
      'sessionRedpackTextSingleMoney': '单个金额',
      'sessionRedpackTextTotalCount': '红包个数',
      'sessionRedpackTextUnitMoney': '元',
      'sessionRedpackTextUnitCount': '个',
      'sessionRedpackHintMoney': '请输入金额',
      'sessionRedpackHintCount': '请输入个数',
      'sessionRedpackHintDesc': '恭喜发财，大吉大利',
      'sessionRedpackButtonSure': '发送红包',
      'sessionRedpackErrorMoney': '请输入正确的金额',
      'sessionRedpackErrorCount': '请输入正确的个数',
      'sessionMessageRealtimeGoing': '正在通话中...',
      'sessionMessageRealtimeMissed': '未接通',
      'sessionMessageRealtimeTotal': '通话时长',
      'sessionMessageRealtimeEndHint': '通话已结束',
      'sessionMessageRealtimeNotHint': '未加入会话',
      'contactHomeActionBtnUserSearchTip': '搜索用户',
      'contactHomeActionBtnTeamCreateTip': '创建群组',
      'contactHomeTabItemWaitships': '好友申请',
      'contactHomeTabItemUserships': '我的好友',
      'contactHomeTabItemTeamships': '我的群组',
      'contactHomeTeamCreateLoading': '创建中...',
      'contactAZListActionBtnSure': '确定',
      'contactAZListActionBtnPlusTip': '添加成员',
      'contactAZListSuffixOfWaitships': ' 个申请',
      'contactAZListSuffixOfUserships': ' 个好友',
      'contactAZListSuffixOfTeamships': ' 个群组',
      'contactAZListSuffixOfTeamusers': ' 个成员',
      'contactAZListWaitshipsApplyEmpty': '申请添加您为好友',
      'contactAZListTeamUsersOwnerHint': '群主',
      'contactAZListTeamUsersAdminHint': '管理',
      'contactAZListTeamUsersBtnAdminY': '设为管理',
      'contactAZListTeamUsersBtnAdminN': '取消管理',
      'contactAZListTeamUsersBtnRemove': '移除',
      'contactAZListTeamUsersBtnQuit': '退出群组',
      'contactAZListTeamUsersActionLoading': '操作中...',
      'contactFinderInputHint': '请输入账号或手机号搜索用户',
      'contactFinderActionBtnSure': '搜索',
      'contactFinderItemResEmptyText': '没有搜索到数据',
      'contactFinderSureLoading': '搜索中...',
      'contactUserInfoActionBtnMenuTip': '显示菜单',
      'contactUserInfoListHeadNoTitle': '账号: ',
      'contactUserInfoListHeadNoEmpty': '未设置',
      'contactUserInfoListItemAliasTitle': '备注名',
      'contactUserInfoListItemAddrTitle': '地区',
      'contactUserInfoListItemDescTitle': '描述',
      'contactUserInfoListItemFromTitle': '来源',
      'contactUserInfoListItemNoticeTitle': '消息提醒',
      'contactUserInfoListItemTopTitle': '置顶聊天',
      'contactUserInfoListItemApplyTitle': '申请信息',
      'contactUserInfoListItemApplyEmpty': '申请添加您为好友',
      'contactUserInfoListItemChatBtnStart': '发起聊天',
      'contactUserInfoListItemApplyBtnSend': '加为好友',
      'contactUserInfoListItemApplyBtnAgree': '同意',
      'contactUserInfoListItemApplyBtnReject': '拒绝',
      'contactUserInfoListItemApplyWaitHint': '已发送好友申请',
      'contactUserInfoMenuItemShareToUser': '分享名片给好友',
      'contactUserInfoMenuItemShareToTeam': '分享名片到群组',
      'contactUserInfoMenuItemReport': '投诉这个用户',
      'contactUserInfoMenuItemRemove': '删除这个好友',
      'contactUserInfoMenuItemCancel': '取消',
      'contactUserInfoUserShipQueryLoading': '加载中...',
      'contactUserInfoUserShipUpdateLoading': '更新中...',
      'contactUserInfoUserShipActionLoading': '操作中...',
      'contactUserInfoUserShipShareFinished': '名片已分享',
      'contactTeamInfoActionBtnMenuTip': '显示菜单',
      'contactTeamInfoListHeadTotalPreffix': '共',
      'contactTeamInfoListHeadTotalSuffix': '人',
      'contactTeamInfoListHeadMemberTitle': '群组成员',
      'contactTeamInfoListItemQrCodeTitle': '群组二维码',
      'contactTeamInfoListItemQrCodeHint': '扫一扫上面的二维码图案，加入该群组',
      'contactTeamInfoListItemNickTitle': '群组名称',
      'contactTeamInfoListItemDescTitle': '群组公告',
      'contactTeamInfoListItemSettingsTitle': '群组权限',
      'contactTeamInfoListItemAliasTitle': '我的群昵称',
      'contactTeamInfoListItemNoticeTitle': '消息提醒',
      'contactTeamInfoListItemTopTitle': '置顶聊天',
      'contactTeamInfoListItemFromTitle': '我加入的方式',
      'contactTeamInfoListItemChatBtnStart': '发起聊天',
      'contactTeamInfoListItemApplyBtnSend': '加入群组',
      'contactTeamInfoMenuItemShareToUser': '分享名片给好友',
      'contactTeamInfoMenuItemShareToTeam': '分享名片到群组',
      'contactTeamInfoMenuItemReport': '投诉这个群组',
      'contactTeamInfoMenuItemRemove': '退出这个群组',
      'contactTeamInfoMenuItemCancel': '取消',
      'contactTeamInfoTeamShipQueryLoading': '加载中...',
      'contactTeamInfoTeamShipUpdateLoading': '更新中...',
      'contactTeamInfoTeamShipActionLoading': '操作中...',
      'contactTeamInfoTeamShipShareFinished': '名片已分享',
      'contactEditorTitlePreffix': '修改',
      'contactEditorActionBtnSave': '确定',
      'contactEditorTeamOnText': '开启',
      'contactEditorTeamOffText': '关闭',
      'contactEditorTeamByfind': '通过搜索加入该群',
      'contactEditorTeamBycode': '通过扫码加入该群',
      'contactEditorTeamBycard': '通过名片加入该群',
      'contactEditorTeamByteam': '群组成员互加好友',
      'contactEditorTeamNotice': '群组资料变化通知',
      'contactEditorTeamSlient': '仅管理员可发消息',
      'contactEditorSaveLoading': '保存中...',
      'contactEditorApplyLoading': '申请中...',
      'usermeHomeActionBtnAppThemeTip': '切换主题',
      'usermeHomeActionBtnMyQrCodeTip': '我的二维码',
      'usermeHomeActionBtnMyQrcodeHint': '扫一扫上面的二维码图案，加我为好友',
      'usermeHomeListHeadMyNoTitle': '账号: ',
      'usermeHomeListHeadMyNoEmpty': '未设置',
      'usermeHomeListItemMyVipCentTitle': '会员中心',
      'usermeHomeListItemMyCollectTitle': '我的收藏',
      'usermeHomeListItemProtoUserTitle': '用户协议',
      'usermeHomeListItemProtoPrivTitle': '隐私政策',
      'usermeHomeListItemSettingsTitle': '应用设置',
      'usermeDetailTitle': '我的信息',
      'usermeDetailListItemNoTitle': '账号',
      'usermeDetailListItemPwdTitle': '密码',
      'usermeDetailListItemNickTitle': '昵称',
      'usermeDetailListItemDescTitle': '描述',
      'usermeDetailListItemPhoneTitle': '手机号码',
      'usermeDetailListItemNameTitle': '真实姓名',
      'usermeDetailListItemCardTitle': '身份证号',
      'usermeDetailListItemSexTitle': '性别',
      'usermeDetailListItemBirthTitle': '生日',
      'usermeDetailListItemAddrTitle': '地区',
      'usermeDetailMenuItemAlbum': '从相册选择',
      'usermeDetailMenuItemCamera': '拍摄新照片',
      'usermeDetailMenuItemCancel': '取消',
      'usermeDetailHeadEditTitle': '编辑图片',
      'usermeDetailSaveLoading': '保存中...',
      'usermeEditorTitlePreffix': '修改',
      'usermeEditorActionBtnSave': '保存',
      'usermeEditorNoHint': '请输入8~32位账号 (字母/数字/下划线)',
      'usermeEditorNoHelper': '账号只能设置一次，且不可修改',
      'usermeEditorPasswordCode': '验证码',
      'usermeEditorPasswordCodeHint': '请输入已绑定手机号的验证码',
      'usermeEditorPasswordPwd': '新密码',
      'usermeEditorPasswordPwdHint': '请输入8~32位新密码',
      'usermeEditorPasswordUnbind': '请先绑定手机号码',
      'usermeEditorPhoneOldCode': '原验证码',
      'usermeEditorPhoneOldCodeHint': '请输入原手机号的验证码',
      'usermeEditorPhoneNewPhone': '新手机号',
      'usermeEditorPhoneNewPhoneHint': '请输入要绑定的新手机号',
      'usermeEditorPhoneNewCode': '新验证码',
      'usermeEditorPhoneNewCodeHint': '请输入新手机号的验证码',
      'usermeEditorRandcodeSend': '发送',
      'usermeEditorChooseBirthday': '选择日期',
      'usermeEditorAddrCountry': '国家',
      'usermeEditorAddrProvince': '省份',
      'usermeEditorAddrCity': '市',
      'usermeEditorAddrArea': '县（区）',
      'usermeEditorSaveLoading': '保存中...',
      'usermeEditorSendLoading': '发送中...',
      'usermeSettingsUserByfind': '通过搜索加我为好友',
      'usermeSettingsUserBycode': '通过扫码加我为好友',
      'usermeSettingsUserBycard': '通过名片加我为好友',
      'usermeSettingsUserByteam': '通过群组加我为好友',
      'usermeSettingsUserNotice': '收到消息有后台通知',
      'usermeSettingsUserSlient': '收到消息有声音提醒',
      'usermeSettingsBtnLogout': '退出登录',
      'usermeSettingsBoxLogoutHint': '您确定要退出登录吗？',
      'usermeSettingsBoxLogoutCancel': '取消',
      'usermeSettingsBoxLogoutSure': '确定',
      'usermeSettingsSaveLoading': '保存中...',
      'usermeSettingsLogoutLoading': '登出中...',
      'androidNotificationChannelMessageName': '新消息通知',
      'androidNotificationChannelMessageDesc': '收到新消息时使用的通知类别',
      'androidNotificationChannelRealtimeName': '音视频通知',
      'androidNotificationChannelRealtimeDesc': '收到音视频邀请时的通知类别',
    },
    'en': {
      'appLoginNormalTitle': 'Sign in with account',
      'appLoginNormalBtnSure': 'Sign in',
      'appLoginNormalThirdMethod': 'Or sign in with:',
      'appLoginNormalNoWechatHint': 'Please install WeChat first',
      'appLoginRegisterTitle': 'Register an account',
      'appLoginRegisterBtnSure': 'Register',
      'appLoginForgetPwdTitle': 'Forget the password',
      'appLoginForgetPwdBtnSure': 'Modify',
      'appLoginPhoneCodeTitle': 'Sign in with mibile',
      'appLoginPhoneCodeBtnSure': 'Sure',
      'appLoginFieldLabelNo': 'Account',
      'appLoginFieldLabelPwd': 'Password',
      'appLoginFieldLabelPhone': 'Phone Number',
      'appLoginFieldLabelCode': 'Verification code',
      'appLoginFieldLabelNewPwd': 'New password',
      'appLoginFieldHintNo': 'Account or phone number',
      'appLoginFieldHintPwd': '8~32 length password',
      'appLoginFieldHintPhone': 'Your phone number',
      'appLoginFieldHintCode': '6 digits verification code',
      'appLoginFieldHintNewNo': '8~32 length (letter/number/underline)',
      'appLoginFieldHintNewPwd': '8~32 length new password',
      'appLoginFieldBtnSendCode': 'Send',
      'appLoginProtoReadAgreeBody': 'Agree ',
      'appLoginProtoReadAgreeAlert': 'You have carefully read and agreed',
      'appLoginProtoBtnUserText': 'User agreement',
      'appLoginProtoAnd': ' and ',
      'appLoginProtoBtnProvText': 'Privacy policy',
      'appLoginProtoAlertBtnNo': 'No',
      'appLoginProtoAlertBtnYes': 'Yes',
      'appLoginSureLoading': 'Signing in...',
      'appLoginSendLoading': 'Sending...',
      'appHomeTabItemCustom1': 'Apps',
      'appHomeTabItemCustom2': 'Infos',
      'appHomeTabItemSession': 'Chat',
      'appHomeTabItemUserme': 'Mine',
      'appHomeUserExpiredHint': 'Your current login status has expired!',
      'appHomeUserExpiredSure': 'I got it',
      'appWebViewActionBtnMenuTip': 'Show menu',
      'appWebViewMenuItemShareToUser': 'Share page to friends',
      'appWebViewMenuItemShareToTeam': 'Share page to teams',
      'appWebViewMenuItemReport': 'Report this page',
      'appWebViewMenuItemReload': 'Reload this page',
      'appWebViewMenuItemCancel': 'Cancel',
      'appWebViewPageShareFinished': 'Html page shared',
      'sessionHomeActionBtnContactTip': 'Contacts',
      'sessionHomeActionBtnQrScanTip': 'Scan qrcode',
      'sessionHomeListItemBtnReaded': 'Mark read',
      'sessionHomeListItemBtnRemove': 'Remove',
      'sessionChatActionBtnDetailTip': 'Session details',
      'sessionChatKeyboardMenuItemGallery': 'Gallery',
      'sessionChatKeyboardMenuItemCamera': 'Camera',
      'sessionChatKeyboardMenuItemVoice': 'Voice call',
      'sessionChatKeyboardMenuItemVideo': 'Video call',
      'sessionChatKeyboardMenuItemScreen': 'Screen share',
      'sessionChatKeyboardMenuItemLocaltion': 'Location share',
      'sessionChatKeyboardMenuItemLocalreal': 'Realtime location',
      'sessionChatKeyboardMenuItemRedpack': 'Red envelope',
      'sessionChatKeyboardInputHint': 'Please use the keyboard to enter',
      'sessionChatImageEditTitle': 'Edit picture',
      'sessionChatTeamusersPickerTitle': 'Select team members',
      'sessionChatRealtimeDeviceIsBusy': 'Device is busy...',
      'sessionChatFileUploadLoading': 'Uploading...',
      'sessionAmapActionBtnSure': 'Send',
      'sessionAmapTitleLocationView': 'Location information',
      'sessionAmapTitleShareMessage': 'Location sharing',
      'sessionAmapTitleRealtimeShare': 'Realtime location sharing',
      'sessionAmapNavigateNameAmap': 'Gaode Maps',
      'sessionAmapNavigateNameBaidu': 'Baidu Maps',
      'sessionAmapNavigateNameTencent': 'Tencent Maps',
      'sessionAmapNavigateNameApple': 'Apple Maps',
      'sessionAmapNavigateNameGoogle': 'Google Maps',
      'sessionAmapNavigateCancel': 'Cancel',
      'sessionAmapPoiListBarTitle': 'Nearby locations',
      'sessionAmapDistanceKilometer': 'km',
      'sessionAmapDistanceMeter': 'm',
      'sessionAmapEncodeLoading': 'Encoding...',
      'sessionAmapUploadLoading': 'Uploading...',
      'sessionRealtimeTextWaiting': 'Waiting...',
      'sessionRealtimeTextChating': 'In calling...',
      'sessionRedpackTitleNormal': 'Normal red envelope',
      'sessionRedpackTitleLuckly': 'Luckly red envelope',
      'sessionRedpackTextSwitchTo': 'Change to',
      'sessionRedpackTextTotalMoney': 'Total amount',
      'sessionRedpackTextSingleMoney': 'Single amount',
      'sessionRedpackTextTotalCount': 'Total count',
      'sessionRedpackTextUnitMoney': 'Yuan(¥)',
      'sessionRedpackTextUnitCount': 'Count',
      'sessionRedpackHintMoney': 'Please enter',
      'sessionRedpackHintCount': 'Please enter',
      'sessionRedpackHintDesc': 'Congratulations on making a fortune',
      'sessionRedpackButtonSure': 'Send red envelope',
      'sessionRedpackErrorMoney': 'Please enter the correct amount',
      'sessionRedpackErrorCount': 'Please enter the correct number',
      'sessionMessageRealtimeGoing': 'In calling...',
      'sessionMessageRealtimeMissed': 'Missed call',
      'sessionMessageRealtimeTotal': 'Call duration',
      'sessionMessageRealtimeEndHint': 'Call ended',
      'sessionMessageRealtimeNotHint': 'Session not joined',
      'contactHomeActionBtnUserSearchTip': 'Search user',
      'contactHomeActionBtnTeamCreateTip': 'Create team',
      'contactHomeTabItemWaitships': 'My applys',
      'contactHomeTabItemUserships': 'My friends',
      'contactHomeTabItemTeamships': 'My teams',
      'contactHomeTeamCreateLoading': 'Creating...',
      'contactAZListActionBtnSure': 'Sure',
      'contactAZListActionBtnPlusTip': 'Add members',
      'contactAZListSuffixOfWaitships': ' applys',
      'contactAZListSuffixOfUserships': ' friends',
      'contactAZListSuffixOfTeamships': ' teams',
      'contactAZListSuffixOfTeamusers': ' members',
      'contactAZListWaitshipsApplyEmpty': 'Apply to add you as a friend',
      'contactAZListTeamUsersOwnerHint': 'Team owner',
      'contactAZListTeamUsersAdminHint': 'Team admin',
      'contactAZListTeamUsersBtnAdminY': 'Set as admin',
      'contactAZListTeamUsersBtnAdminN': 'Unset admin',
      'contactAZListTeamUsersBtnRemove': 'Remove',
      'contactAZListTeamUsersBtnQuit': 'Quit',
      'contactAZListTeamUsersActionLoading': 'Operating...',
      'contactFinderInputHint': 'Account or phone number of users',
      'contactFinderActionBtnSure': 'Search',
      'contactFinderItemResEmptyText': 'Not data found',
      'contactFinderSureLoading': 'Searhing...',
      'contactUserInfoActionBtnMenuTip': 'Show menu',
      'contactUserInfoListHeadNoTitle': 'Account: ',
      'contactUserInfoListHeadNoEmpty': 'Account not set',
      'contactUserInfoListItemAliasTitle': 'Alias',
      'contactUserInfoListItemAddrTitle': 'Region',
      'contactUserInfoListItemDescTitle': 'Describe',
      'contactUserInfoListItemFromTitle': 'From',
      'contactUserInfoListItemNoticeTitle': 'Message notice',
      'contactUserInfoListItemTopTitle': 'Top chating',
      'contactUserInfoListItemApplyTitle': 'Apply message',
      'contactUserInfoListItemApplyEmpty': 'Apply to add you as a friend',
      'contactUserInfoListItemChatBtnStart': 'Start chating',
      'contactUserInfoListItemApplyBtnSend': 'Apply to be a friend',
      'contactUserInfoListItemApplyBtnAgree': 'Agree',
      'contactUserInfoListItemApplyBtnReject': 'Reject',
      'contactUserInfoListItemApplyWaitHint': 'Friend apply has been sent',
      'contactUserInfoMenuItemShareToUser': 'Share card to friends',
      'contactUserInfoMenuItemShareToTeam': 'Share card to teams',
      'contactUserInfoMenuItemReport': 'Report this user',
      'contactUserInfoMenuItemRemove': 'Delete this friend',
      'contactUserInfoMenuItemCancel': 'Cancel',
      'contactUserInfoUserShipQueryLoading': 'Loading...',
      'contactUserInfoUserShipUpdateLoading': 'Updating...',
      'contactUserInfoUserShipActionLoading': 'Operating...',
      'contactUserInfoUserShipShareFinished': 'Business card shared',
      'contactTeamInfoActionBtnMenuTip': 'Show menu',
      'contactTeamInfoListHeadTotalPreffix': 'Total ',
      'contactTeamInfoListHeadTotalSuffix': ' members',
      'contactTeamInfoListHeadMemberTitle': 'Team members',
      'contactTeamInfoListItemQrCodeTitle': 'Team qrcode',
      'contactTeamInfoListItemQrCodeHint': 'Scan the qrcode and join the team',
      'contactTeamInfoListItemNickTitle': 'Team nick',
      'contactTeamInfoListItemDescTitle': 'Team describe',
      'contactTeamInfoListItemSettingsTitle': 'Team permissions',
      'contactTeamInfoListItemAliasTitle': 'My alias in team',
      'contactTeamInfoListItemNoticeTitle': 'Message notice',
      'contactTeamInfoListItemTopTitle': 'Top chating',
      'contactTeamInfoListItemFromTitle': 'The way I join in',
      'contactTeamInfoListItemChatBtnStart': 'Start chating',
      'contactTeamInfoListItemApplyBtnSend': 'Join in the team',
      'contactTeamInfoMenuItemShareToUser': 'Share card to friends',
      'contactTeamInfoMenuItemShareToTeam': 'Share card to teams',
      'contactTeamInfoMenuItemReport': 'Report this team',
      'contactTeamInfoMenuItemRemove': 'Quit this team',
      'contactTeamInfoMenuItemCancel': 'Cancel',
      'contactTeamInfoTeamShipQueryLoading': 'Loading...',
      'contactTeamInfoTeamShipUpdateLoading': 'Updating...',
      'contactTeamInfoTeamShipActionLoading': 'Operating...',
      'contactTeamInfoTeamShipShareFinished': 'Business card shared',
      'contactEditorTitlePreffix': 'Modify ',
      'contactEditorActionBtnSave': 'Sure',
      'contactEditorTeamOnText': 'ON',
      'contactEditorTeamOffText': 'OFF',
      'contactEditorTeamByfind': 'Join team by searching',
      'contactEditorTeamBycode': 'Join team by scan qrcode',
      'contactEditorTeamBycard': 'Join team by shared card',
      'contactEditorTeamByteam': 'Add friends each other in team',
      'contactEditorTeamNotice': 'Team data change notification',
      'contactEditorTeamSlient': 'Only admin can send messages',
      'contactEditorSaveLoading': 'Saving...',
      'contactEditorApplyLoading': 'Applying...',
      'usermeHomeActionBtnAppThemeTip': 'Switch themes',
      'usermeHomeActionBtnMyQrCodeTip': 'My qrcode',
      'usermeHomeActionBtnMyQrcodeHint': 'Scan the qrcode and add me as a friend',
      'usermeHomeListHeadMyNoTitle': 'Account: ',
      'usermeHomeListHeadMyNoEmpty': 'Account not set',
      'usermeHomeListItemMyVipCentTitle': 'Vip center',
      'usermeHomeListItemMyCollectTitle': 'My collections',
      'usermeHomeListItemProtoUserTitle': 'User agreement',
      'usermeHomeListItemProtoPrivTitle': 'Privacy policy',
      'usermeHomeListItemSettingsTitle': 'Application settings',
      'usermeDetailTitle': 'My information',
      'usermeDetailListItemNoTitle': 'Account',
      'usermeDetailListItemPwdTitle': 'Password',
      'usermeDetailListItemNickTitle': 'Nick name',
      'usermeDetailListItemDescTitle': 'Describe',
      'usermeDetailListItemPhoneTitle': 'Phone number',
      'usermeDetailListItemNameTitle': 'Real name',
      'usermeDetailListItemCardTitle': 'Ident card',
      'usermeDetailListItemSexTitle': 'Sex',
      'usermeDetailListItemBirthTitle': 'Birthday',
      'usermeDetailListItemAddrTitle': 'Region',
      'usermeDetailMenuItemAlbum': 'Select from album',
      'usermeDetailMenuItemCamera': 'Take a new photo',
      'usermeDetailMenuItemCancel': 'Cancel',
      'usermeDetailHeadEditTitle': 'Edit picture',
      'usermeDetailSaveLoading': 'Saving...',
      'usermeEditorTitlePreffix': 'Modify ',
      'usermeEditorActionBtnSave': 'Save',
      'usermeEditorNoHint': '8~32 length (letter/number/underline)',
      'usermeEditorNoHelper': 'Can only be set once and cannot be modified',
      'usermeEditorPasswordCode': 'Verification code',
      'usermeEditorPasswordCodeHint': '6 digits of bound phone number',
      'usermeEditorPasswordPwd': 'New password',
      'usermeEditorPasswordPwdHint': '8~32 length new password',
      'usermeEditorPasswordUnbind': 'Please bind the phone number first',
      'usermeEditorPhoneOldCode': 'Original verification code',
      'usermeEditorPhoneOldCodeHint': '6 digits of original phone number',
      'usermeEditorPhoneNewPhone': 'New phone number',
      'usermeEditorPhoneNewPhoneHint': 'New phone number to bind',
      'usermeEditorPhoneNewCode': 'New verification code',
      'usermeEditorPhoneNewCodeHint': '6 digits of new phone number',
      'usermeEditorRandcodeSend': 'Send',
      'usermeEditorChooseBirthday': 'Choose date',
      'usermeEditorAddrCountry': 'Country',
      'usermeEditorAddrProvince': 'Province',
      'usermeEditorAddrCity': 'City',
      'usermeEditorAddrArea': 'Area',
      'usermeEditorSaveLoading': 'Saving...',
      'usermeEditorSendLoading': 'Sending...',
      'usermeSettingsUserByfind': 'Add me as a friend by searching',
      'usermeSettingsUserBycode': 'Add me as a friend by my qrcode',
      'usermeSettingsUserBycard': 'Add me as a friend by my card',
      'usermeSettingsUserByteam': 'Add me as a friend by the team',
      'usermeSettingsUserNotice': 'Msg has background notification',
      'usermeSettingsUserSlient': 'Msg has foreground sound remind',
      'usermeSettingsBtnLogout': 'Sign out',
      'usermeSettingsBoxLogoutHint': 'Are you sure sign out?',
      'usermeSettingsBoxLogoutCancel': 'Cancel',
      'usermeSettingsBoxLogoutSure': 'Sure',
      'usermeSettingsSaveLoading': 'Saving...',
      'usermeSettingsLogoutLoading': 'Signing out...',
      'androidNotificationChannelMessageName': 'New message notification',
      'androidNotificationChannelMessageDesc': 'Notification category to use when new messages are received',
      'androidNotificationChannelRealtimeName': 'Audio and video notification',
      'androidNotificationChannelRealtimeDesc': 'Notification category when receiving audio and video invitation',
    },
  };
}

class _AppLocalizationsDelegate extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  Future<AppLocalizations> load(Locale locale) => Future.value(AppLocalizations(locale: locale));

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;

  @override
  bool isSupported(Locale locale) => true;
}
