import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart';

import 'app_config.dart';
import 'app_locale.dart';
import 'app_router.dart';
import 'contact_editor.dart';
import 'widget/widget_avator.dart';
import 'widget/widget_divider.dart';
import 'widget/widget_sheet.dart';

///
///群组信息页
///
class ContactTeamInfo extends StatefulWidget {
  /* ******************************** instance content ******************************** */
  ///初始的群组信息
  final Team initteam;

  ///初始的关系实例
  final TeamShip initship;

  const ContactTeamInfo._({Key? key, required this.initteam, required this.initship}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _ContactTeamInfoState();

  /* ******************************** static content ******************************** */
  ///根据群组数据创建
  static void pushRoute(BuildContext context, {required ObjectId tid, required ObjectId fid, required int from, bool pushReplacement = false}) async {
    final navigator = Navigator.of(context);
    TeamShip? initship = AppConfig.client.getTeamShip(tid);
    if (initship == null) {
      SmartDialog.showLoading(msg: AppLocalizations.contactTeamInfoTeamShipQueryLoading);
      final result = await AppConfig.client.teamShipQuery(tid: tid, fid: fid, from: from);
      SmartDialog.dismiss();
      if (result.ok) {
        initship = AppConfig.client.getTeamShip(tid) ?? result.extra;
      } else {
        SmartDialog.showToast(result.desc);
      }
    }
    if (initship != null) {
      final initteam = AppConfig.client.getTeam(tid);
      if (pushReplacement) {
        navigator.pushReplacement(MaterialPageRoute(builder: (context) => ContactTeamInfo._(initteam: initteam, initship: initship!)));
      } else {
        navigator.push(MaterialPageRoute(builder: (context) => ContactTeamInfo._(initteam: initteam, initship: initship!)));
      }
    }
  }
}

enum _ContactTeamInfoMenuItem { share, report, remove }

class _ContactTeamInfoState extends State<ContactTeamInfo> {
  static const _heroContactTeamInfoHeadTag = '_heroContactTeamInfoHeadTag';
  late Team _currteam;
  late TeamShip _currship;

  @override
  void initState() {
    super.initState();
    AppConfig.logDebug(['ContactTeamInfo.initState()']);
    _currteam = widget.initteam;
    _currship = widget.initship;
    AppConfig.client.setOnTeamFetchedWatcher(_clientCommonListener, remove: false);
    AppConfig.client.setOnTeamUpdateListener(_clientCommonListener, remove: false);
    AppConfig.client.setOnTeamShipUpdateListener(_clientCommonListener, remove: false);
  }

  @override
  void dispose() {
    AppConfig.logDebug(['ContactTeamInfo.dispose()']);
    AppConfig.client.setOnTeamFetchedWatcher(_clientCommonListener, remove: true);
    AppConfig.client.setOnTeamUpdateListener(_clientCommonListener, remove: true);
    AppConfig.client.setOnTeamShipUpdateListener(_clientCommonListener, remove: true);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    if (ComTools.isTeamShipFromSystem(_currship)) {
      return Scaffold(
        appBar: _buildAppBar(themeData, []),
        body: _buildBodySys(themeData),
      );
    } else if (_currship.state == Constant.shipStateNone) {
      return Scaffold(
        appBar: _buildAppBar(themeData, [_ContactTeamInfoMenuItem.report]),
        body: _buildBodyNone(themeData),
      );
    } else if (_currship.state == Constant.shipStatePass) {
      return Scaffold(
        appBar: _buildAppBar(themeData, [_ContactTeamInfoMenuItem.share, _ContactTeamInfoMenuItem.report, _ContactTeamInfoMenuItem.remove]),
        body: _buildBodyPass(themeData),
      );
    } else {
      return Scaffold(
        appBar: _buildAppBar(themeData, []),
      );
    }
  }

  AppBar _buildAppBar(ThemeData themeData, List<_ContactTeamInfoMenuItem> menuItems) {
    if (menuItems.isEmpty) {
      return AppBar(
        backgroundColor: themeData.cardColor,
      );
    } else {
      return AppBar(
        backgroundColor: themeData.cardColor,
        actions: [
          IconButton(
            icon: const Icon(Icons.more_horiz_outlined),
            tooltip: AppLocalizations.contactTeamInfoActionBtnMenuTip,
            onPressed: () => _buildAppBarMenuItem(menuItems),
          ),
        ],
      );
    }
  }

  void _buildAppBarMenuItem(List<_ContactTeamInfoMenuItem> menuItems) {
    final itemDatas = <WidgetSheetItem>[];
    for (var element in menuItems) {
      switch (element) {
        case _ContactTeamInfoMenuItem.share:
          itemDatas.add(WidgetSheetItem(0, AppLocalizations.contactTeamInfoMenuItemShareToUser));
          itemDatas.add(WidgetSheetItem(1, AppLocalizations.contactTeamInfoMenuItemShareToTeam));
          break;
        case _ContactTeamInfoMenuItem.report:
          itemDatas.add(WidgetSheetItem(2, AppLocalizations.contactTeamInfoMenuItemReport));
          break;
        case _ContactTeamInfoMenuItem.remove:
          itemDatas.add(WidgetSheetItem(3, AppLocalizations.contactTeamInfoMenuItemRemove, color: Colors.redAccent));
          break;
      }
    }
    WidgetSheet.showBottomTextSheet(context, itemDatas, cancelText: AppLocalizations.contactTeamInfoMenuItemCancel).then((value) async {
      switch (value) {
        case 0:
          AppRouter.pushContactUserShipsPickerPage(context, title: AppLocalizations.contactTeamInfoMenuItemShareToUser).then((value) {
            if (value == null) return;
            for (var element in value) {
              AppConfig.client.messageSendShareCardTeam(
                sid: element.sid,
                from: Constant.msgFromUser,
                title: ComTools.formatTeamNick(_currteam),
                body: _currteam.desc,
                shareCardId: _currteam.id,
                shareIconUrl: _currteam.icon,
                shareHeadUrl: _currteam.head,
              );
            }
            SmartDialog.showToast(AppLocalizations.contactTeamInfoTeamShipShareFinished);
          });
          break;
        case 1:
          AppRouter.pushContactTeamShipsPickerPage(context, title: AppLocalizations.contactTeamInfoMenuItemShareToTeam).then((value) {
            if (value == null) return;
            for (var element in value) {
              AppConfig.client.messageSendShareCardTeam(
                sid: element.sid,
                from: Constant.msgFromTeam,
                title: ComTools.formatTeamNick(_currteam),
                body: _currteam.desc,
                shareCardId: _currteam.id,
                shareIconUrl: _currteam.icon,
                shareHeadUrl: _currteam.head,
              );
            }
            SmartDialog.showToast(AppLocalizations.contactTeamInfoTeamShipShareFinished);
          });
          break;
        case 2:
          break;
        case 3:
          SmartDialog.showLoading(msg: AppLocalizations.contactTeamInfoTeamShipActionLoading);
          final result = await AppConfig.client.teamShipNone(tid: _currteam.id, uid: AppConfig.client.user.id);
          SmartDialog.dismiss();
          SmartDialog.showToast(result.desc);
          break;
      }
    });
  }

  Widget _buildBodySys(themeData) {
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: ComTools.isTeamShipFromSystem(_currship)
                    ? InkWell(
                        child: Hero(tag: _heroContactTeamInfoHeadTag, child: WidgetAvator(type: WidgetAvatorType.large, url: _currteam.icon, urlList: _currteam.head, onFormatUrl: AppConfig.formatAttachUrl)),
                        onTap: () => AppRouter.pushImageViewerPage(context, urlList: [_currteam.icon], heroList: [_heroContactTeamInfoHeadTag], onFormatUrl: AppConfig.formatAttachUrl),
                      )
                    : WidgetAvator(type: WidgetAvatorType.large, single: ComTools.isTeamShipFromSystem(_currship), url: _currteam.icon, urlList: _currteam.head, onFormatUrl: AppConfig.formatAttachUrl),
                title: Text(ComTools.formatTeamNick(_currteam), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(_currteam.desc),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactTeamInfoListItemNoticeTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.notice, onChanged: (value) => _onNoticeItemTap()),
                onTap: _onNoticeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactTeamInfoListItemTopTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.top, onChanged: (value) => _onTopItemTap()),
                onTap: _onTopItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Icon(Icons.sms_outlined, color: themeData.colorScheme.secondary, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.contactTeamInfoListItemChatBtnStart, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary)),
                  ],
                ),
                onTap: _onDialogItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  Widget _buildBodyNone(ThemeData themeData) {
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: WidgetAvator(type: WidgetAvatorType.large, single: ComTools.isTeamShipFromSystem(_currship), url: _currteam.icon, urlList: _currteam.head, onFormatUrl: AppConfig.formatAttachUrl),
                title: Text(ComTools.formatTeamNick(_currteam), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(
                  '${AppLocalizations.contactTeamInfoListHeadTotalPreffix}${_currteam.member}${AppLocalizations.contactTeamInfoListHeadTotalSuffix}',
                  style: themeData.textTheme.subtitle1,
                ),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactTeamInfoListItemDescTitle, style: themeData.textTheme.subtitle1),
                title: Text(_currteam.desc, textAlign: TextAlign.right),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Icon(Icons.group_add_outlined, color: themeData.colorScheme.secondary, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.contactTeamInfoListItemApplyBtnSend, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary)),
                  ],
                ),
                onTap: _onApplyItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  Widget _buildBodyPass(ThemeData themeData) {
    final isAdmin = ComTools.isTeamAdmin(_currteam, AppConfig.client.user.id);
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: WidgetAvator(type: WidgetAvatorType.large, single: ComTools.isTeamShipFromSystem(_currship), url: _currteam.icon, urlList: _currteam.head, onFormatUrl: AppConfig.formatAttachUrl),
                title: Text(ComTools.formatTeamNick(_currteam), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(
                  '${AppLocalizations.contactTeamInfoListHeadTotalPreffix}${_currteam.member}${AppLocalizations.contactTeamInfoListHeadTotalSuffix}',
                  style: themeData.textTheme.subtitle1,
                ),
                trailing: AppConfig.infoListTileTailArrowIC,
                onTap: () => AppRouter.pushContactTeamUsersPage(context, title: AppLocalizations.contactTeamInfoListHeadMemberTitle, team: _currteam, picker: false),
              ),
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                leading: Text(AppLocalizations.contactTeamInfoListItemQrCodeTitle, style: themeData.textTheme.subtitle1),
                title: Align(
                  alignment: Alignment.centerRight,
                  child: Icon(Icons.qr_code, size: AppConfig.bigGlobalIconReSize, color: themeData.textTheme.caption?.color),
                ),
                trailing: AppConfig.infoListTileTailArrowIC,
                onTap: () => AppRouter.pushQrcodeViewerPage(
                  context,
                  title: AppLocalizations.contactTeamInfoListItemQrCodeTitle,
                  data: AppConfig.formatIdentUrl(team: _currteam),
                  icon: const Icon(Icons.group_outlined, color: Colors.grey),
                  nick: ComTools.formatTeamNick(_currteam),
                  hint: AppLocalizations.contactTeamInfoListItemQrCodeHint,
                  logo: WidgetAvator(type: WidgetAvatorType.large, single: ComTools.isTeamShipFromSystem(_currship), url: _currteam.icon, urlList: _currteam.head, onFormatUrl: AppConfig.formatAttachUrl),
                ),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: isAdmin ? null : AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactTeamInfoListItemNickTitle, style: themeData.textTheme.subtitle1),
                title: Text(ComTools.formatTeamNick(_currteam), textAlign: TextAlign.right),
                trailing: isAdmin ? AppConfig.infoListTileTailArrowIC : null,
                onTap: isAdmin ? () => AppRouter.pushContactEditorPage(context, fieldTitle: AppLocalizations.contactTeamInfoListItemNickTitle, editorType: ContactEditorType.teamNick, targetShip: _currship) : null,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: isAdmin ? null : AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactTeamInfoListItemDescTitle, style: themeData.textTheme.subtitle1),
                title: Text(_currteam.desc, textAlign: TextAlign.right),
                trailing: isAdmin ? AppConfig.infoListTileTailArrowIC : null,
                onTap: isAdmin ? () => AppRouter.pushContactEditorPage(context, fieldTitle: AppLocalizations.contactTeamInfoListItemDescTitle, editorType: ContactEditorType.teamDesc, targetShip: _currship) : null,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                leading: Text(AppLocalizations.contactTeamInfoListItemSettingsTitle, style: themeData.textTheme.subtitle1),
                trailing: AppConfig.infoListTileTailArrowIC,
                onTap: () => AppRouter.pushContactEditorPage(context, fieldTitle: AppLocalizations.contactTeamInfoListItemSettingsTitle, editorType: ContactEditorType.teamSettings, targetShip: _currship),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                leading: Text(AppLocalizations.contactTeamInfoListItemAliasTitle, style: themeData.textTheme.subtitle1),
                title: Text(_currship.alias, textAlign: TextAlign.right),
                trailing: AppConfig.infoListTileTailArrowIC,
                onTap: () => AppRouter.pushContactEditorPage(context, fieldTitle: AppLocalizations.contactTeamInfoListItemAliasTitle, editorType: ContactEditorType.teamshipAlias, targetShip: _currship),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactTeamInfoListItemFromTitle, style: themeData.textTheme.subtitle1),
                title: Text(AppLocalizations.modelConstMapText(_currship.from), textAlign: TextAlign.right),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactTeamInfoListItemNoticeTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.notice, onChanged: (value) => _onNoticeItemTap()),
                onTap: _onNoticeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactTeamInfoListItemTopTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.top, onChanged: (value) => _onTopItemTap()),
                onTap: _onTopItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Icon(Icons.sms_outlined, color: themeData.colorScheme.secondary, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.contactTeamInfoListItemChatBtnStart, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary)),
                  ],
                ),
                onTap: _onDialogItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  void _onApplyItemTap() async {
    SmartDialog.showLoading(msg: AppLocalizations.contactTeamInfoTeamShipActionLoading);
    final result = await AppConfig.client.teamShipApply(tid: _currteam.id, fid: _currship.fid, from: _currship.from, apply: '');
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onNoticeItemTap() async {
    final ship = TeamShipDirty();
    ship.notice = !_currship.notice;
    SmartDialog.showLoading(msg: AppLocalizations.contactTeamInfoTeamShipUpdateLoading);
    final result = await AppConfig.client.teamShipUpdate(id: _currship.id, fields: ship.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onTopItemTap() async {
    final ship = TeamShipDirty();
    ship.top = !_currship.top;
    SmartDialog.showLoading(msg: AppLocalizations.contactTeamInfoTeamShipUpdateLoading);
    final result = await AppConfig.client.teamShipUpdate(id: _currship.id, fields: ship.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onDialogItemTap() async {
    AppRouter.pushSessionChatPage(context, session: AppConfig.client.createSession(teamship: _currship), pushAndRemoveUntilFirst: true);
    if (!_currship.dialog) {
      final ship = TeamShipDirty();
      ship.dialog = true;
      AppConfig.client.teamShipUpdate(id: _currship.id, fields: ship.data);
    }
  }

  void _clientCommonListener(EasyPacket packet) {
    final localship = AppConfig.client.getTeamShip(_currteam.id);
    if (localship == null) {
      AppConfig.client.teamShipQuery(tid: _currteam.id, fid: _currship.fid, from: _currship.from).then((value) {
        if (value.ok) {
          if (mounted) {
            setState(() {
              _currship = AppConfig.client.getTeamShip(_currteam.id) ?? value.extra!;
            });
          }
        }
      });
    } else {
      if (mounted) {
        setState(() {
          _currship = localship;
        });
      }
    }
  }
}
