import 'package:flutter/material.dart';
import 'package:flutter_smart_dialog/flutter_smart_dialog.dart';
import 'package:imsdk_client_core/imsdk_client_core.dart';

import 'app_config.dart';
import 'app_locale.dart';
import 'app_router.dart';
import 'contact_editor.dart';
import 'widget/widget_avator.dart';
import 'widget/widget_divider.dart';
import 'widget/widget_sheet.dart';

///
/// 用户信息页
///
class ContactUserInfo extends StatefulWidget {
  /* ******************************** instance content ******************************** */
  ///初始的用户信息
  final User inituser;

  ///初始的关系实例
  final UserShip initship;

  const ContactUserInfo._({Key? key, required this.inituser, required this.initship}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _ContactUserInfoState();

  /* ******************************** static content ******************************** */
  ///根据用户数据创建
  static void pushRoute(BuildContext context, {required ObjectId uid, required ObjectId fid, required int from, bool pushReplacement = false}) async {
    if (uid == AppConfig.client.user.id) {
      AppRouter.pushUsermeDetailPage(context);
      return;
    }
    final navigator = Navigator.of(context);
    UserShip? initship = AppConfig.client.getWaitShip(uid) ?? AppConfig.client.getUserShip(uid);
    if (initship == null) {
      SmartDialog.showLoading(msg: AppLocalizations.contactUserInfoUserShipQueryLoading);
      final result = await AppConfig.client.userShipQuery(uid: uid, fid: fid, from: from);
      SmartDialog.dismiss();
      if (result.ok) {
        initship = AppConfig.client.getWaitShip(uid) ?? AppConfig.client.getUserShip(uid) ?? result.extra;
      } else {
        SmartDialog.showToast(result.desc);
      }
    }
    if (initship != null) {
      final inituser = AppConfig.client.getUser(uid);
      if (pushReplacement) {
        navigator.pushReplacement(MaterialPageRoute(builder: (context) => ContactUserInfo._(inituser: inituser, initship: initship!)));
      } else {
        navigator.push(MaterialPageRoute(builder: (context) => ContactUserInfo._(inituser: inituser, initship: initship!)));
      }
    }
  }
}

enum _ContactUserInfoMenuItem { share, report, remove }

class _ContactUserInfoState extends State<ContactUserInfo> {
  static const _heroContactUserInfoHeadTag = '_heroContactUserInfoHeadTag';
  late User _curruser;
  late UserShip _currship;

  @override
  void initState() {
    super.initState();
    AppConfig.logDebug(['ContactUserInfo.initState()']);
    _curruser = widget.inituser;
    _currship = widget.initship;
    AppConfig.client.setOnUserFetchedWatcher(_clientCommonListener, remove: false);
    AppConfig.client.setOnWaitShipUpdateListener(_clientCommonListener, remove: false);
    AppConfig.client.setOnUserShipUpdateListener(_clientCommonListener, remove: false);
  }

  @override
  void dispose() {
    AppConfig.logDebug(['ContactUserInfo.dispose()']);
    AppConfig.client.setOnUserFetchedWatcher(_clientCommonListener, remove: true);
    AppConfig.client.setOnWaitShipUpdateListener(_clientCommonListener, remove: true);
    AppConfig.client.setOnUserShipUpdateListener(_clientCommonListener, remove: true);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final themeData = Theme.of(context);
    if (ComTools.isUserShipFromSystem(_currship)) {
      return Scaffold(
        appBar: _buildAppBar(themeData, []),
        body: _buildBodySys(themeData),
      );
    } else if (_currship.state == Constant.shipStateNone) {
      return Scaffold(
        appBar: _buildAppBar(themeData, [_ContactUserInfoMenuItem.report]),
        body: _buildBodyNone(themeData),
      );
    } else if (_currship.state == Constant.shipStateWait) {
      return Scaffold(
        appBar: _buildAppBar(themeData, [_ContactUserInfoMenuItem.report]),
        body: _buildBodyWait(themeData),
      );
    } else if (_currship.state == Constant.shipStatePass) {
      return Scaffold(
        appBar: _buildAppBar(themeData, [_ContactUserInfoMenuItem.share, _ContactUserInfoMenuItem.report, _ContactUserInfoMenuItem.remove]),
        body: _buildBodyPass(themeData),
      );
    } else {
      return Scaffold(
        appBar: _buildAppBar(themeData, []),
      );
    }
  }

  AppBar _buildAppBar(ThemeData themeData, List<_ContactUserInfoMenuItem> menuItems) {
    if (menuItems.isEmpty) {
      return AppBar(
        backgroundColor: themeData.cardColor,
      );
    } else {
      return AppBar(
        backgroundColor: themeData.cardColor,
        actions: [
          IconButton(
            icon: const Icon(Icons.more_horiz_outlined),
            tooltip: AppLocalizations.contactUserInfoActionBtnMenuTip,
            onPressed: () => _buildAppBarMenuItem(menuItems),
          ),
        ],
      );
    }
  }

  void _buildAppBarMenuItem(List<_ContactUserInfoMenuItem> menuItems) {
    final itemDatas = <WidgetSheetItem>[];
    for (var element in menuItems) {
      switch (element) {
        case _ContactUserInfoMenuItem.share:
          itemDatas.add(WidgetSheetItem(0, AppLocalizations.contactUserInfoMenuItemShareToUser));
          itemDatas.add(WidgetSheetItem(1, AppLocalizations.contactUserInfoMenuItemShareToTeam));
          break;
        case _ContactUserInfoMenuItem.report:
          itemDatas.add(WidgetSheetItem(2, AppLocalizations.contactUserInfoMenuItemReport));
          break;
        case _ContactUserInfoMenuItem.remove:
          itemDatas.add(WidgetSheetItem(3, AppLocalizations.contactUserInfoMenuItemRemove, color: Colors.redAccent));
          break;
      }
    }
    WidgetSheet.showBottomTextSheet(context, itemDatas, cancelText: AppLocalizations.contactUserInfoMenuItemCancel).then((value) async {
      switch (value) {
        case 0:
          AppRouter.pushContactUserShipsPickerPage(context, title: AppLocalizations.contactUserInfoMenuItemShareToUser).then((value) {
            if (value == null) return;
            for (var element in value) {
              AppConfig.client.messageSendShareCardUser(
                sid: element.sid,
                from: Constant.msgFromUser,
                title: ComTools.formatUserNick(_curruser),
                body: AppLocalizations.modelConstMapText(_curruser.sex),
                shareCardId: _curruser.id,
                shareIconUrl: _curruser.icon,
                shareHeadUrl: _curruser.head,
              );
            }
            SmartDialog.showToast(AppLocalizations.contactUserInfoUserShipShareFinished);
          });
          break;
        case 1:
          AppRouter.pushContactTeamShipsPickerPage(context, title: AppLocalizations.contactUserInfoMenuItemShareToTeam).then((value) {
            if (value == null) return;
            for (var element in value) {
              AppConfig.client.messageSendShareCardUser(
                sid: element.sid,
                from: Constant.msgFromTeam,
                title: ComTools.formatUserNick(_curruser),
                body: AppLocalizations.modelConstMapText(_curruser.sex),
                shareCardId: _curruser.id,
                shareIconUrl: _curruser.icon,
                shareHeadUrl: _curruser.head,
              );
            }
            SmartDialog.showToast(AppLocalizations.contactUserInfoUserShipShareFinished);
          });
          break;
        case 2:
          break;
        case 3:
          _onApplyRejectItemTap();
          break;
      }
    });
  }

  Widget _buildBodySys(ThemeData themeData) {
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: InkWell(
                  child: Hero(tag: _heroContactUserInfoHeadTag, child: WidgetAvator(type: WidgetAvatorType.large, url: _curruser.icon, urlList: _curruser.head, onFormatUrl: AppConfig.formatAttachUrl)),
                  onTap: () => AppRouter.pushImageViewerPage(context, urlList: [_curruser.icon], heroList: [_heroContactUserInfoHeadTag], onFormatUrl: AppConfig.formatAttachUrl),
                ),
                title: Text(ComTools.formatUserShipNick(_currship, _curruser), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(_curruser.desc),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactUserInfoListItemNoticeTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.notice, onChanged: (value) => _onNoticeItemTap()),
                onTap: _onNoticeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactUserInfoListItemTopTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.top, onChanged: (value) => _onTopItemTap()),
                onTap: _onTopItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Icon(Icons.sms_outlined, color: themeData.colorScheme.secondary, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.contactUserInfoListItemChatBtnStart, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary)),
                  ],
                ),
                onTap: _onDialogItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  Widget _buildBodyNone(ThemeData themeData) {
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: InkWell(
                  child: Hero(tag: _heroContactUserInfoHeadTag, child: WidgetAvator(type: WidgetAvatorType.large, url: _curruser.icon, urlList: _curruser.head, onFormatUrl: AppConfig.formatAttachUrl)),
                  onTap: () => AppRouter.pushImageViewerPage(context, urlList: [_curruser.icon], heroList: [_heroContactUserInfoHeadTag], onFormatUrl: AppConfig.formatAttachUrl),
                ),
                title: Text(ComTools.formatUserNick(_curruser), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(
                  '${AppLocalizations.contactUserInfoListHeadNoTitle}${ComTools.formatUserNo(_curruser, empty: AppLocalizations.contactUserInfoListHeadNoEmpty)}',
                  style: themeData.textTheme.subtitle1,
                ),
                trailing: AppConfig.getUserSexIcon(_curruser.sex),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemAddrTitle, style: themeData.textTheme.subtitle1),
                title: Text(ComTools.formatUserShowArea(_curruser), textAlign: TextAlign.right),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemDescTitle, style: themeData.textTheme.subtitle1),
                title: Text(_curruser.desc, textAlign: TextAlign.right),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Icon(Icons.person_add_outlined, color: themeData.colorScheme.secondary, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.contactUserInfoListItemApplyBtnSend, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary)),
                  ],
                ),
                onTap: () => AppRouter.pushContactEditorPage(
                  context,
                  fieldTitle: AppLocalizations.contactUserInfoListItemApplyBtnSend,
                  editorType: ContactEditorType.usershipApply,
                  targetShip: _currship,
                  inputLabel: AppLocalizations.contactUserInfoListItemApplyTitle,
                ),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  Widget _buildBodyWait(ThemeData themeData) {
    final isApply = _currship.uid == _curruser.id;
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: InkWell(
                  child: Hero(tag: _heroContactUserInfoHeadTag, child: WidgetAvator(type: WidgetAvatorType.large, url: _curruser.icon, urlList: _curruser.head, onFormatUrl: AppConfig.formatAttachUrl)),
                  onTap: () => AppRouter.pushImageViewerPage(context, urlList: [_curruser.icon], heroList: [_heroContactUserInfoHeadTag], onFormatUrl: AppConfig.formatAttachUrl),
                ),
                title: Text(ComTools.formatUserNick(_curruser), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(
                  '${AppLocalizations.contactUserInfoListHeadNoTitle}${ComTools.formatUserNo(_curruser, empty: AppLocalizations.contactUserInfoListHeadNoEmpty)}',
                  style: themeData.textTheme.subtitle1,
                ),
                trailing: AppConfig.getUserSexIcon(_curruser.sex),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemAddrTitle, style: themeData.textTheme.subtitle1),
                title: Text(ComTools.formatUserShowArea(_curruser), textAlign: TextAlign.right),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemDescTitle, style: themeData.textTheme.subtitle1),
                title: Text(_curruser.desc, textAlign: TextAlign.right),
              ),
              isApply ? WidgetDivider.forListTileLeadingNone : const SizedBox(),
              isApply
                  ? ListTile(
                      contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                      leading: Text(AppLocalizations.contactUserInfoListItemFromTitle, style: themeData.textTheme.subtitle1),
                      title: Text(AppLocalizations.modelConstMapText(_currship.from), textAlign: TextAlign.right),
                    )
                  : const SizedBox(),
              isApply ? WidgetDivider.forListTileLeadingNone : const SizedBox(),
              isApply
                  ? ListTile(
                      contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                      leading: Text(AppLocalizations.contactUserInfoListItemApplyTitle, style: themeData.textTheme.subtitle1),
                      title: Text(ComTools.formatWaitShipApply(_currship, empty: AppLocalizations.contactUserInfoListItemApplyEmpty), textAlign: TextAlign.right),
                    )
                  : const SizedBox(),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              isApply
                  ? Row(
                      children: [
                        Expanded(
                          child: ListTile(
                            contentPadding: AppConfig.infoListTileItemPadding,
                            title: Text(AppLocalizations.contactUserInfoListItemApplyBtnReject, style: themeData.textTheme.subtitle1?.copyWith(color: Colors.redAccent), textAlign: TextAlign.center),
                            onTap: _onApplyRejectItemTap,
                          ),
                        ),
                        WidgetDivider.forListTileInfoItemVertical,
                        Expanded(
                          child: ListTile(
                            contentPadding: AppConfig.infoListTileItemPadding,
                            title: Text(AppLocalizations.contactUserInfoListItemApplyBtnAgree, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary), textAlign: TextAlign.center),
                            onTap: _onApplyAgreeItemTap,
                          ),
                        ),
                      ],
                    )
                  : ListTile(
                      contentPadding: AppConfig.infoListTileItemPadding,
                      title: Text(AppLocalizations.contactUserInfoListItemApplyWaitHint, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.textTheme.caption?.color), textAlign: TextAlign.center),
                    ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  Widget _buildBodyPass(ThemeData themeData) {
    return ListView(
      physics: AppConfig.bodyGlobalScrollPhysics,
      children: [
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              ListTile(
                contentPadding: AppConfig.infoListTileHeadPadding,
                leading: InkWell(
                  child: Hero(tag: _heroContactUserInfoHeadTag, child: WidgetAvator(type: WidgetAvatorType.large, url: _curruser.icon, urlList: _curruser.head, onFormatUrl: AppConfig.formatAttachUrl)),
                  onTap: () => AppRouter.pushImageViewerPage(context, urlList: [_curruser.icon], heroList: [_heroContactUserInfoHeadTag], onFormatUrl: AppConfig.formatAttachUrl),
                ),
                title: Text(ComTools.formatUserNick(_curruser), style: themeData.textTheme.subtitle1?.copyWith(fontWeight: FontWeight.bold)),
                subtitle: Text(
                  '${AppLocalizations.contactUserInfoListHeadNoTitle}${ComTools.formatUserNo(_curruser, empty: AppLocalizations.contactUserInfoListHeadNoEmpty)}',
                  style: themeData.textTheme.subtitle1,
                ),
                trailing: AppConfig.getUserSexIcon(_curruser.sex),
              ),
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                leading: Text(AppLocalizations.contactUserInfoListItemAliasTitle, style: themeData.textTheme.subtitle1),
                title: Text(_currship.alias, textAlign: TextAlign.right),
                trailing: AppConfig.infoListTileTailArrowIC,
                onTap: () => AppRouter.pushContactEditorPage(
                  context,
                  fieldTitle: AppLocalizations.contactUserInfoListItemAliasTitle,
                  editorType: ContactEditorType.usershipAlias,
                  targetShip: _currship,
                ),
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemAddrTitle, style: themeData.textTheme.subtitle1),
                title: Text(ComTools.formatUserShowArea(_curruser), textAlign: TextAlign.right),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemDescTitle, style: themeData.textTheme.subtitle1),
                title: Text(_curruser.desc, textAlign: TextAlign.right),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.left),
                leading: Text(AppLocalizations.contactUserInfoListItemFromTitle, style: themeData.textTheme.subtitle1),
                title: Text(AppLocalizations.modelConstMapText(_currship.from), textAlign: TextAlign.right),
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactUserInfoListItemNoticeTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.notice, onChanged: (value) => _onNoticeItemTap()),
                onTap: _onNoticeItemTap,
              ),
              WidgetDivider.forListTileLeadingNone,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding.copyWith(right: AppConfig.infoListTileItemPadding.right / 2),
                leading: Text(AppLocalizations.contactUserInfoListItemTopTitle, style: themeData.textTheme.subtitle1),
                trailing: Switch(value: _currship.top, onChanged: (value) => _onTopItemTap()),
                onTap: _onTopItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
        Ink(
          color: themeData.cardColor,
          child: Column(
            children: [
              WidgetDivider.forFull,
              ListTile(
                contentPadding: AppConfig.infoListTileItemPadding,
                title: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Icon(Icons.sms_outlined, color: themeData.colorScheme.secondary, size: AppConfig.bigGlobalIconReSize),
                    SizedBox(width: AppConfig.infoListTileItemPadding.left / 2),
                    Text(AppLocalizations.contactUserInfoListItemChatBtnStart, style: themeData.textTheme.subtitle1?.copyWith(color: themeData.colorScheme.secondary)),
                  ],
                ),
                onTap: _onDialogItemTap,
              ),
              WidgetDivider.forFull,
            ],
          ),
        ),
        AppConfig.cardGlobalSpaceMedium,
      ],
    );
  }

  void _onApplyRejectItemTap() async {
    SmartDialog.showLoading(msg: AppLocalizations.contactUserInfoUserShipActionLoading);
    final result = await AppConfig.client.userShipNone(uid: _curruser.id);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onApplyAgreeItemTap() async {
    SmartDialog.showLoading(msg: AppLocalizations.contactUserInfoUserShipActionLoading);
    final result = await AppConfig.client.userShipPass(uid: _curruser.id);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onNoticeItemTap() async {
    final ship = UserShipDirty();
    ship.notice = !_currship.notice;
    SmartDialog.showLoading(msg: AppLocalizations.contactUserInfoUserShipUpdateLoading);
    final result = await AppConfig.client.userShipUpdate(id: _currship.id, fields: ship.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onTopItemTap() async {
    final ship = UserShipDirty();
    ship.top = !_currship.top;
    SmartDialog.showLoading(msg: AppLocalizations.contactUserInfoUserShipUpdateLoading);
    final result = await AppConfig.client.userShipUpdate(id: _currship.id, fields: ship.data);
    SmartDialog.dismiss();
    SmartDialog.showToast(result.desc);
  }

  void _onDialogItemTap() async {
    AppRouter.pushSessionChatPage(context, session: AppConfig.client.createSession(usership: _currship), pushAndRemoveUntilFirst: true);
    if (!_currship.dialog) {
      final ship = UserShipDirty();
      ship.dialog = true;
      AppConfig.client.userShipUpdate(id: _currship.id, fields: ship.data);
    }
  }

  void _clientCommonListener(EasyPacket packet) {
    final localship = AppConfig.client.getWaitShip(_curruser.id) ?? AppConfig.client.getUserShip(_curruser.id);
    if (localship == null) {
      AppConfig.client.userShipQuery(uid: _curruser.id, fid: _currship.fid, from: _currship.from).then((value) {
        if (value.ok) {
          if (mounted) {
            setState(() {
              _currship = AppConfig.client.getWaitShip(_curruser.id) ?? AppConfig.client.getUserShip(_curruser.id) ?? value.extra!;
            });
          }
        }
      });
    } else {
      if (mounted) {
        setState(() {
          _currship = localship;
        });
      }
    }
  }
}
