import 'package:flutter/material.dart';

///
///徽章标记位置
///
enum WidgetBadgeAlign {
  ///左上角
  topLeft,

  ///垂直居中、水平居左
  centerLeft,

  ///正中心
  center,

  ///垂直居中、水平居右
  centerRight,

  ///右上角
  topRight,
}

///
///徽章标记
///
class WidgetBadge extends StatelessWidget {
  static const smallMargin = 16.0;
  static const middleMargin = 32.0;
  static const largeMargin = 48.0;
  static const hugeMargin = 64.0;

  final Icon? icon;
  final int count;
  final double size;
  final double margin;
  final Color color;
  final Color darkColor;
  final double textSize;
  final Color textColor;
  final WidgetBadgeAlign align;
  final bool dotOnly;
  final bool darkMode;

  const WidgetBadge({
    Key? key,
    this.icon,
    required this.count,
    this.size = 16,
    this.margin = smallMargin,
    this.color = Colors.red,
    this.darkColor = const Color(0xFF909090),
    this.textSize = 10,
    this.textColor = Colors.white,
    this.align = WidgetBadgeAlign.topRight,
    this.dotOnly = false,
    this.darkMode = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.center,
      clipBehavior: Clip.none,
      children: [icon ?? const SizedBox(), _buildBadge(context)],
    );
  }

  Widget _buildBadge(BuildContext context) {
    final themeData = Theme.of(context);
    if (count > 0) {
      if (dotOnly) {
        return Positioned(
          top: (align == WidgetBadgeAlign.centerLeft || align == WidgetBadgeAlign.center || align == WidgetBadgeAlign.centerRight) ? null : -margin / 8,
          left: (align == WidgetBadgeAlign.topLeft || align == WidgetBadgeAlign.centerLeft) ? -margin / 4 : null,
          right: (align == WidgetBadgeAlign.topRight || align == WidgetBadgeAlign.centerRight) ? -margin / 4 : null,
          child: Container(
            width: size / 2,
            height: size / 2,
            decoration: BoxDecoration(shape: BoxShape.circle, color: darkMode ? darkColor : color),
          ),
        );
      } else {
        return Positioned(
          top: (align == WidgetBadgeAlign.centerLeft || align == WidgetBadgeAlign.center || align == WidgetBadgeAlign.centerRight) ? null : -margin / 4,
          left: (align == WidgetBadgeAlign.topLeft || align == WidgetBadgeAlign.centerLeft) ? -margin / 2 : null,
          right: (align == WidgetBadgeAlign.topRight || align == WidgetBadgeAlign.centerRight) ? -margin / 2 : null,
          child: Container(
            width: size,
            height: size,
            decoration: BoxDecoration(shape: BoxShape.circle, color: darkMode ? darkColor : color),
            alignment: Alignment.center,
            child: Text(count > 99 ? '...' : '$count', style: TextStyle(color: textColor, fontSize: textSize, height: 1)),
          ),
        );
      }
    } else {
      if (darkMode) {
        return Icon(
          Icons.notifications_off_outlined,
          size: size,
          color: themeData.textTheme.caption?.color,
        );
      } else {
        return const SizedBox();
      }
    }
  }
}
