import 'package:flutter/material.dart';

///
///对话框
///
class WidgetDialog {
  ///alert对话框
  static Future<bool?> alert(BuildContext context, {String? title, String body = '', Widget? bodyWidget, String? leftText, String? rightText, Color? leftColor, Color? rightColor, bool rightOnly = false}) {
    const radius = Radius.circular(8);
    final themeData = Theme.of(context);
    final padding = EdgeInsets.only(left: 16, right: 16, top: title == null ? 32 : 16, bottom: title == null ? 32 : 24);
    final textStyle = themeData.textTheme.subtitle1;
    const btnHeight = 52.0;
    return showDialog<bool>(
      context: context,
      barrierDismissible: false,
      builder: (BuildContext context) {
        return WillPopScope(
          child: AlertDialog(
            elevation: 0,
            scrollable: true,
            backgroundColor: themeData.cardColor,
            shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(radius)),
            titlePadding: padding.copyWith(bottom: 0),
            contentPadding: padding,
            buttonPadding: EdgeInsets.zero,
            title: title == null ? null : Text(title, textAlign: TextAlign.center, style: textStyle?.copyWith(fontWeight: FontWeight.bold)),
            content: bodyWidget ?? Text(body, textAlign: TextAlign.center, style: textStyle),
            actions: [
              const Divider(),
              SizedBox(
                height: btnHeight,
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.stretch,
                  children: <Widget>[
                    rightOnly
                        ? const SizedBox()
                        : Expanded(
                            child: MaterialButton(
                              padding: EdgeInsets.zero,
                              shape: const RoundedRectangleBorder(borderRadius: BorderRadius.only(bottomLeft: radius)),
                              child: Text(leftText ?? 'Cancel', style: textStyle?.copyWith(color: leftColor)),
                              onPressed: () => Navigator.pop(context, false),
                            ),
                          ),
                    rightOnly ? const SizedBox() : const VerticalDivider(),
                    Expanded(
                      child: MaterialButton(
                        padding: EdgeInsets.zero,
                        shape: RoundedRectangleBorder(borderRadius: BorderRadius.only(bottomRight: radius, bottomLeft: rightOnly ? radius : Radius.zero)),
                        child: Text(rightText ?? 'Sure', style: textStyle?.copyWith(color: rightColor)),
                        onPressed: () => Navigator.pop(context, true),
                      ),
                    ),
                  ],
                ),
              )
            ],
          ),
          onWillPop: () async => false, //拦截返回按钮
        );
      },
    );
  }
}
