import 'package:extended_image/extended_image.dart';
import 'package:flutter/material.dart';

///
///图片显示
///
class WidgetImage extends StatelessWidget {
  final String url;
  final String Function(String val) onFormatUrl;
  final BoxFit fit;
  final double blankBoxSize;
  final Widget? errorWidget;
  final Widget? loadingWidget;

  const WidgetImage({
    Key? key,
    required this.url,
    required this.onFormatUrl,
    this.fit = BoxFit.cover,
    this.blankBoxSize = 58,
    this.errorWidget,
    this.loadingWidget,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ExtendedImage.network(
      onFormatUrl(url),
      fit: fit,
      loadStateChanged: (imageState) {
        switch (imageState.extendedImageLoadState) {
          case LoadState.loading:
            return Container(
              alignment: Alignment.center,
              width: blankBoxSize,
              height: blankBoxSize,
              child: loadingWidget ?? SizedBox(width: blankBoxSize * 0.4, height: blankBoxSize * 0.4, child: const CircularProgressIndicator(strokeWidth: 2.0)),
            );
          case LoadState.failed:
            return Container(
              alignment: Alignment.center,
              width: blankBoxSize,
              height: blankBoxSize,
              child: errorWidget ?? Icon(Icons.broken_image_outlined, size: blankBoxSize * 0.5, color: Colors.grey),
            );
          case LoadState.completed:
            return null;
        }
      },
    );
  }
}
