import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:mobile_scanner/mobile_scanner.dart';

///
///二维码扫描
///
class WidgetQrscan extends StatefulWidget {
  final SystemUiOverlayStyle systemUiOverlayStyle;
  final double borderRadius;
  final double borderLength;
  final double borderWidth;
  final double cutRectSize;
  final double iconBtnSize;
  final bool Function(BuildContext context, String result) callback;
  const WidgetQrscan({
    Key? key,
    required this.systemUiOverlayStyle,
    this.borderRadius = 10,
    this.borderLength = 30,
    this.borderWidth = 5,
    this.cutRectSize = 280,
    this.iconBtnSize = 38,
    required this.callback,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _WidgetQrscanState();
}

class _WidgetQrscanState extends State<WidgetQrscan> {
  final _cannerController = MobileScannerController(facing: CameraFacing.back, torchEnabled: false);

  bool _callbacking = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _cannerController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final queryData = MediaQuery.of(context);
    return Scaffold(
      extendBodyBehindAppBar: true,
      appBar: AppBar(
        backgroundColor: Colors.transparent,
        systemOverlayStyle: widget.systemUiOverlayStyle,
        automaticallyImplyLeading: false,
        toolbarHeight: 0,
      ),
      body: Stack(
        alignment: Alignment.center,
        children: <Widget>[
          MobileScanner(
            allowDuplicates: false,
            controller: _cannerController,
            onDetect: _onScannerDetect,
          ),
          Positioned(
            bottom: (queryData.size.height - widget.cutRectSize) / 4,
            left: (queryData.size.width - widget.cutRectSize) / 2,
            child: IconButton(
              icon: Icon(Icons.highlight, color: Colors.white, size: widget.iconBtnSize),
              onPressed: () => _cannerController.toggleTorch(),
            ),
          ),
          Positioned(
            bottom: (queryData.size.height - widget.cutRectSize) / 4,
            child: IconButton(
              icon: Icon(Icons.flip_camera_ios, color: Colors.white, size: widget.iconBtnSize),
              onPressed: () => _cannerController.switchCamera(),
            ),
          ),
          Positioned(
            bottom: (queryData.size.height - widget.cutRectSize) / 4,
            right: (queryData.size.width - widget.cutRectSize) / 2,
            child: IconButton(
              icon: Icon(Icons.close, color: Colors.white, size: widget.iconBtnSize),
              onPressed: () => Navigator.pop(context),
            ),
          ),
        ],
      ),
    );
  }

  void _onScannerDetect(Barcode barcode, MobileScannerArguments? args) {
    if (barcode.rawValue == null) return;
    if (_callbacking) return;
    _callbacking = true; //加锁
    if (!widget.callback(context, barcode.rawValue!)) {
      _callbacking = false; //解锁
    }
  }
}
